/***************************************************************************
 *                                  _   _ ____  _
 *  Project                     ___| | | |  _ \| |
 *                             / __| | | | |_) | |
 *                            | (__| |_| |  _ <| |___
 *                             \___|\___/|_| \_\_____|
 *
 * Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.
 *
 * This software is licensed as described in the file COPYING, which
 * you should have received as part of this distribution. The terms
 * are also available at https://curl.se/docs/copyright.html.
 *
 * You may opt to use, copy, modify, merge, publish, distribute and/or sell
 * copies of the Software, and permit persons to whom the Software is
 * furnished to do so, under the terms of the COPYING file.
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
 * KIND, either express or implied.
 *
 * SPDX-License-Identifier: curl
 *
 ***************************************************************************/
#include "test.h"
#include "memdebug.h"
#include <limits.h>

/* This source code is generated by mk-lib1521.pl ! */

struct testdata {
    char *blaha;
};

#define LO LONG_MIN
#define HI LONG_MAX
#define OFF_LO (curl_off_t) LO
#define OFF_HI (curl_off_t) CURL_OFF_T_MAX
#define OFF_NO (curl_off_t) 0

static size_t writecb(char *buffer, size_t size, size_t nitems,
                      void *outstream)
{
  (void)buffer;
  (void)size;
  (void)nitems;
  (void)outstream;
  return 0;
}

static size_t readcb(char *buffer,
              size_t size,
              size_t nitems,
              void *instream)
{
  (void)buffer;
  (void)size;
  (void)nitems;
  (void)instream;
  return 0;
}

static void errlongzero(const char *name, CURLcode code, int lineno)
{
  printf("%s set to 0 returned %d, \"%s\" on line %d\n",
         name, code, curl_easy_strerror(code), lineno);
}

static void errlong(const char *name, CURLcode code, int lineno)
{
  switch(code) {
  case CURLE_UNSUPPORTED_PROTOCOL:
    if(!strcmp("CURLOPT_HTTP_VERSION", name))
      return;
    break;
  case CURLE_NOT_BUILT_IN:
    if(!strcmp("CURLOPT_HTTPAUTH", name))
      return;
    if(!strcmp("CURLOPT_PROXYAUTH", name))
      return;
    if(!strcmp("CURLOPT_SOCKS5_AUTH", name))
      return;
    break;
  default:
    break;
  }

  printf("%s set to non-zero returned %d, \"%s\" on line %d\n",
         name, code, curl_easy_strerror(code), lineno);
}

static void errstring(const char *name, CURLcode code, int lineno)
{
  /* allow this set of options to return CURLE_BAD_FUNCTION_ARGUMENT
     when given a strange string input */
  switch(code) {
  case CURLE_BAD_FUNCTION_ARGUMENT:
    if(!strcmp("CURLOPT_DNS_LOCAL_IP4", name))
      return;
    if(!strcmp("CURLOPT_DNS_LOCAL_IP6", name))
      return;
    if(!strcmp("CURLOPT_DNS_SERVERS", name))
      return;
    if(!strcmp("CURLOPT_PROXY_TLSAUTH_TYPE", name))
      return;
    if(!strcmp("CURLOPT_SSLENGINE", name))
      return;
    if(!strcmp("CURLOPT_TLSAUTH_TYPE", name))
      return;
     break;
  case CURLE_UNSUPPORTED_PROTOCOL:
    if(!strcmp("CURLOPT_PROTOCOLS_STR", name))
      return;
    if(!strcmp("CURLOPT_REDIR_PROTOCOLS_STR", name))
      return;
    break;
  case CURLE_SSL_ENGINE_NOTFOUND:
    if(!strcmp("CURLOPT_SSLENGINE", name))
      return;
    break;
  default:
    break;
  }

  printf("%s set to a string returned %d, \"%s\" on line %d\n",
         name, code, curl_easy_strerror(code), lineno);
}

static void err(const char *name, CURLcode val, int lineno)
{
  printf("%s returned %d, \"%s\" on line %d\n",
         name, val, curl_easy_strerror(val), lineno);
}

static void errnull(const char *name, CURLcode val, int lineno)
{
  printf("%s set to NULL returned %d, \"%s\" on line %d\n",
         name, val, curl_easy_strerror(val), lineno);
}

static void geterr(const char *name, CURLcode val, int lineno)
{
  printf("CURLINFO_%s returned %d, \"%s\" on line %d\n",
         name, val, curl_easy_strerror(val), lineno);
}

static curl_progress_callback progresscb;
static curl_write_callback headercb;
static curl_debug_callback debugcb;
static curl_trailer_callback trailercb;
static curl_ssl_ctx_callback ssl_ctx_cb;
static curl_ioctl_callback ioctlcb;
static curl_sockopt_callback sockoptcb;
static curl_opensocket_callback opensocketcb;
static curl_seek_callback seekcb;
static curl_sshkeycallback ssh_keycb;
static curl_sshhostkeycallback ssh_hostkeycb;
static curl_chunk_bgn_callback chunk_bgn_cb;
static curl_chunk_end_callback chunk_end_cb;
static curl_fnmatch_callback fnmatch_cb;
static curl_closesocket_callback closesocketcb;
static curl_xferinfo_callback xferinfocb;
static curl_hstsread_callback hstsreadcb;
static curl_hstswrite_callback hstswritecb;
static curl_resolver_start_callback resolver_start_cb;
static curl_prereq_callback prereqcb;

/* long options that are okay to return
   CURLE_BAD_FUNCTION_ARGUMENT */
static bool bad_long(CURLcode res, int check)
{
  if(res != CURLE_BAD_FUNCTION_ARGUMENT)
    return 0; /* not okay */

  if(check < CURLOPTTYPE_OBJECTPOINT) {
    /* LONG */
    return 1;
  }
  else if((check >= CURLOPTTYPE_OFF_T) &&
          (check < CURLOPTTYPE_BLOB)) {
    /* OFF_T */
    return 1;
  }
  return 0;
}

/* macro to check the first setopt of an option which then is allowed to get a
   non-existing function return code back */
#define present(x) ((x != CURLE_NOT_BUILT_IN) && (x != CURLE_UNKNOWN_OPTION))

CURLcode test(char *URL)
{
  CURL *curl = NULL;
  CURL *dep = NULL;
  CURLSH *share = NULL;
  char errorbuffer[CURL_ERROR_SIZE];
  void *conv_from_network_cb = NULL;
  void *conv_to_network_cb = NULL;
  void *conv_from_utf8_cb = NULL;
  void *interleavecb = NULL;
  char *stringpointerextra = (char *)"moooo";
  struct curl_slist *slist = NULL;
  struct curl_httppost *httppost = NULL;
  curl_mime *mimepost = NULL;
  FILE *stream = stderr;
  struct testdata object;
  char *charp;
  long val;
  curl_off_t oval;
  double dval;
  curl_socket_t sockfd;
  struct curl_certinfo *certinfo;
  struct curl_tlssessioninfo *tlssession;
  struct curl_blob blob = { (void *)"silly", 5, 0};
  CURLcode res = CURLE_OK;
  (void)URL; /* not used */
  global_init(CURL_GLOBAL_ALL);
  easy_init(dep);
  easy_init(curl);
  share = curl_share_init();
  if(!share) {
    res = CURLE_OUT_OF_MEMORY;
    goto test_cleanup;
  }

  CURL_IGNORE_DEPRECATION(

  /****** Verify CURLOPT_WRITEDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_WRITEDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_WRITEDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_WRITEDATA, NULL);
      if(res)
        errnull("CURLOPT_WRITEDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_URL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_URL, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_URL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_URL, NULL);
      if(res)
        errnull("CURLOPT_URL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PORT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PORT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PORT))
      errlongzero("CURLOPT_PORT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PORT, 22L);
      if(res && !bad_long(res, CURLOPT_PORT))
        errlong("CURLOPT_PORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PORT, LO);
      if(res && !bad_long(res, CURLOPT_PORT))
        errlong("CURLOPT_PORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PORT, HI);
      if(res && !bad_long(res, CURLOPT_PORT))
        errlong("CURLOPT_PORT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY, NULL);
      if(res)
        errnull("CURLOPT_PROXY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_USERPWD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_USERPWD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_USERPWD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_USERPWD, NULL);
      if(res)
        errnull("CURLOPT_USERPWD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYUSERPWD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYUSERPWD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXYUSERPWD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYUSERPWD, NULL);
      if(res)
        errnull("CURLOPT_PROXYUSERPWD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RANGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RANGE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_RANGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RANGE, NULL);
      if(res)
        errnull("CURLOPT_RANGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_READDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_READDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_READDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_READDATA, NULL);
      if(res)
        errnull("CURLOPT_READDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ERRORBUFFER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, errorbuffer);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_ERRORBUFFER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, NULL);
      if(res)
        errnull("CURLOPT_ERRORBUFFER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_WRITEFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION,
                           writecb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_WRITEFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_WRITEFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_READFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_READFUNCTION,
                           readcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_READFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_READFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_READFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TIMEOUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TIMEOUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TIMEOUT))
      errlongzero("CURLOPT_TIMEOUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT, 22L);
      if(res && !bad_long(res, CURLOPT_TIMEOUT))
        errlong("CURLOPT_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT, LO);
      if(res && !bad_long(res, CURLOPT_TIMEOUT))
        errlong("CURLOPT_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT, HI);
      if(res && !bad_long(res, CURLOPT_TIMEOUT))
        errlong("CURLOPT_TIMEOUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_INFILESIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_INFILESIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_INFILESIZE))
      errlongzero("CURLOPT_INFILESIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE, 22L);
      if(res && !bad_long(res, CURLOPT_INFILESIZE))
        errlong("CURLOPT_INFILESIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE, LO);
      if(res && !bad_long(res, CURLOPT_INFILESIZE))
        errlong("CURLOPT_INFILESIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE, HI);
      if(res && !bad_long(res, CURLOPT_INFILESIZE))
        errlong("CURLOPT_INFILESIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POSTFIELDS ******/
  (void)curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 0);
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POSTFIELDS, stringpointerextra);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_POSTFIELDS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDS, NULL);
      if(res)
        errnull("CURLOPT_POSTFIELDS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_REFERER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_REFERER, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_REFERER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_REFERER, NULL);
      if(res)
        errnull("CURLOPT_REFERER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTPPORT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTPPORT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_FTPPORT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTPPORT, NULL);
      if(res)
        errnull("CURLOPT_FTPPORT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_USERAGENT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_USERAGENT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_USERAGENT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_USERAGENT, NULL);
      if(res)
        errnull("CURLOPT_USERAGENT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_LOW_SPEED_LIMIT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_LOW_SPEED_LIMIT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_LOW_SPEED_LIMIT))
      errlongzero("CURLOPT_LOW_SPEED_LIMIT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_LIMIT, 22L);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_LIMIT))
        errlong("CURLOPT_LOW_SPEED_LIMIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_LIMIT, LO);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_LIMIT))
        errlong("CURLOPT_LOW_SPEED_LIMIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_LIMIT, HI);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_LIMIT))
        errlong("CURLOPT_LOW_SPEED_LIMIT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_LOW_SPEED_TIME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_LOW_SPEED_TIME, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_LOW_SPEED_TIME))
      errlongzero("CURLOPT_LOW_SPEED_TIME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_TIME, 22L);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_TIME))
        errlong("CURLOPT_LOW_SPEED_TIME", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_TIME, LO);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_TIME))
        errlong("CURLOPT_LOW_SPEED_TIME", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOW_SPEED_TIME, HI);
      if(res && !bad_long(res, CURLOPT_LOW_SPEED_TIME))
        errlong("CURLOPT_LOW_SPEED_TIME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RESUME_FROM ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RESUME_FROM, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_RESUME_FROM))
      errlongzero("CURLOPT_RESUME_FROM", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM, 22L);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM))
        errlong("CURLOPT_RESUME_FROM", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM, LO);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM))
        errlong("CURLOPT_RESUME_FROM", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM, HI);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM))
        errlong("CURLOPT_RESUME_FROM", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COOKIE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COOKIE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_COOKIE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COOKIE, NULL);
      if(res)
        errnull("CURLOPT_COOKIE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTPHEADER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTPHEADER, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HTTPHEADER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTPHEADER, NULL);
      if(res)
        errnull("CURLOPT_HTTPHEADER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTPPOST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTPPOST, httppost);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HTTPPOST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTPPOST, NULL);
      if(res)
        errnull("CURLOPT_HTTPPOST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLCERT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLCERT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSLCERT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLCERT, NULL);
      if(res)
        errnull("CURLOPT_SSLCERT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_KEYPASSWD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_KEYPASSWD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_KEYPASSWD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_KEYPASSWD, NULL);
      if(res)
        errnull("CURLOPT_KEYPASSWD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CRLF ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CRLF, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CRLF))
      errlongzero("CURLOPT_CRLF", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CRLF, 22L);
      if(res && !bad_long(res, CURLOPT_CRLF))
        errlong("CURLOPT_CRLF", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CRLF, LO);
      if(res && !bad_long(res, CURLOPT_CRLF))
        errlong("CURLOPT_CRLF", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CRLF, HI);
      if(res && !bad_long(res, CURLOPT_CRLF))
        errlong("CURLOPT_CRLF", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_QUOTE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_QUOTE, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_QUOTE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_QUOTE, NULL);
      if(res)
        errnull("CURLOPT_QUOTE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HEADERDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HEADERDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HEADERDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HEADERDATA, NULL);
      if(res)
        errnull("CURLOPT_HEADERDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COOKIEFILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COOKIEFILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_COOKIEFILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COOKIEFILE, NULL);
      if(res)
        errnull("CURLOPT_COOKIEFILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLVERSION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLVERSION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSLVERSION))
      errlongzero("CURLOPT_SSLVERSION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLVERSION, 22L);
      if(res && !bad_long(res, CURLOPT_SSLVERSION))
        errlong("CURLOPT_SSLVERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSLVERSION, LO);
      if(res && !bad_long(res, CURLOPT_SSLVERSION))
        errlong("CURLOPT_SSLVERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSLVERSION, HI);
      if(res && !bad_long(res, CURLOPT_SSLVERSION))
        errlong("CURLOPT_SSLVERSION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TIMECONDITION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TIMECONDITION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TIMECONDITION))
      errlongzero("CURLOPT_TIMECONDITION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TIMECONDITION, 22L);
      if(res && !bad_long(res, CURLOPT_TIMECONDITION))
        errlong("CURLOPT_TIMECONDITION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMECONDITION, LO);
      if(res && !bad_long(res, CURLOPT_TIMECONDITION))
        errlong("CURLOPT_TIMECONDITION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMECONDITION, HI);
      if(res && !bad_long(res, CURLOPT_TIMECONDITION))
        errlong("CURLOPT_TIMECONDITION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TIMEVALUE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TIMEVALUE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TIMEVALUE))
      errlongzero("CURLOPT_TIMEVALUE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE, 22L);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE))
        errlong("CURLOPT_TIMEVALUE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE, LO);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE))
        errlong("CURLOPT_TIMEVALUE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE, HI);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE))
        errlong("CURLOPT_TIMEVALUE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CUSTOMREQUEST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CUSTOMREQUEST, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_CUSTOMREQUEST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CUSTOMREQUEST, NULL);
      if(res)
        errnull("CURLOPT_CUSTOMREQUEST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_STDERR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_STDERR, stream);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_STDERR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_STDERR, NULL);
      if(res)
        errnull("CURLOPT_STDERR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POSTQUOTE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POSTQUOTE, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_POSTQUOTE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POSTQUOTE, NULL);
      if(res)
        errnull("CURLOPT_POSTQUOTE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_VERBOSE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_VERBOSE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_VERBOSE))
      errlongzero("CURLOPT_VERBOSE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_VERBOSE, 22L);
      if(res && !bad_long(res, CURLOPT_VERBOSE))
        errlong("CURLOPT_VERBOSE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_VERBOSE, LO);
      if(res && !bad_long(res, CURLOPT_VERBOSE))
        errlong("CURLOPT_VERBOSE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_VERBOSE, HI);
      if(res && !bad_long(res, CURLOPT_VERBOSE))
        errlong("CURLOPT_VERBOSE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HEADER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HEADER, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HEADER))
      errlongzero("CURLOPT_HEADER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HEADER, 22L);
      if(res && !bad_long(res, CURLOPT_HEADER))
        errlong("CURLOPT_HEADER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HEADER, LO);
      if(res && !bad_long(res, CURLOPT_HEADER))
        errlong("CURLOPT_HEADER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HEADER, HI);
      if(res && !bad_long(res, CURLOPT_HEADER))
        errlong("CURLOPT_HEADER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NOPROGRESS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NOPROGRESS))
      errlongzero("CURLOPT_NOPROGRESS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 22L);
      if(res && !bad_long(res, CURLOPT_NOPROGRESS))
        errlong("CURLOPT_NOPROGRESS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOPROGRESS, LO);
      if(res && !bad_long(res, CURLOPT_NOPROGRESS))
        errlong("CURLOPT_NOPROGRESS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOPROGRESS, HI);
      if(res && !bad_long(res, CURLOPT_NOPROGRESS))
        errlong("CURLOPT_NOPROGRESS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NOBODY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NOBODY, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NOBODY))
      errlongzero("CURLOPT_NOBODY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NOBODY, 22L);
      if(res && !bad_long(res, CURLOPT_NOBODY))
        errlong("CURLOPT_NOBODY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOBODY, LO);
      if(res && !bad_long(res, CURLOPT_NOBODY))
        errlong("CURLOPT_NOBODY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOBODY, HI);
      if(res && !bad_long(res, CURLOPT_NOBODY))
        errlong("CURLOPT_NOBODY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FAILONERROR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FAILONERROR, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FAILONERROR))
      errlongzero("CURLOPT_FAILONERROR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FAILONERROR, 22L);
      if(res && !bad_long(res, CURLOPT_FAILONERROR))
        errlong("CURLOPT_FAILONERROR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FAILONERROR, LO);
      if(res && !bad_long(res, CURLOPT_FAILONERROR))
        errlong("CURLOPT_FAILONERROR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FAILONERROR, HI);
      if(res && !bad_long(res, CURLOPT_FAILONERROR))
        errlong("CURLOPT_FAILONERROR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_UPLOAD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_UPLOAD, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_UPLOAD))
      errlongzero("CURLOPT_UPLOAD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD, 22L);
      if(res && !bad_long(res, CURLOPT_UPLOAD))
        errlong("CURLOPT_UPLOAD", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD, LO);
      if(res && !bad_long(res, CURLOPT_UPLOAD))
        errlong("CURLOPT_UPLOAD", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD, HI);
      if(res && !bad_long(res, CURLOPT_UPLOAD))
        errlong("CURLOPT_UPLOAD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POST, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_POST))
      errlongzero("CURLOPT_POST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POST, 22L);
      if(res && !bad_long(res, CURLOPT_POST))
        errlong("CURLOPT_POST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POST, LO);
      if(res && !bad_long(res, CURLOPT_POST))
        errlong("CURLOPT_POST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POST, HI);
      if(res && !bad_long(res, CURLOPT_POST))
        errlong("CURLOPT_POST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DIRLISTONLY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DIRLISTONLY, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DIRLISTONLY))
      errlongzero("CURLOPT_DIRLISTONLY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DIRLISTONLY, 22L);
      if(res && !bad_long(res, CURLOPT_DIRLISTONLY))
        errlong("CURLOPT_DIRLISTONLY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DIRLISTONLY, LO);
      if(res && !bad_long(res, CURLOPT_DIRLISTONLY))
        errlong("CURLOPT_DIRLISTONLY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DIRLISTONLY, HI);
      if(res && !bad_long(res, CURLOPT_DIRLISTONLY))
        errlong("CURLOPT_DIRLISTONLY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_APPEND ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_APPEND, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_APPEND))
      errlongzero("CURLOPT_APPEND", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_APPEND, 22L);
      if(res && !bad_long(res, CURLOPT_APPEND))
        errlong("CURLOPT_APPEND", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_APPEND, LO);
      if(res && !bad_long(res, CURLOPT_APPEND))
        errlong("CURLOPT_APPEND", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_APPEND, HI);
      if(res && !bad_long(res, CURLOPT_APPEND))
        errlong("CURLOPT_APPEND", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NETRC ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NETRC, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NETRC))
      errlongzero("CURLOPT_NETRC", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NETRC, 22L);
      if(res && !bad_long(res, CURLOPT_NETRC))
        errlong("CURLOPT_NETRC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NETRC, LO);
      if(res && !bad_long(res, CURLOPT_NETRC))
        errlong("CURLOPT_NETRC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NETRC, HI);
      if(res && !bad_long(res, CURLOPT_NETRC))
        errlong("CURLOPT_NETRC", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FOLLOWLOCATION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FOLLOWLOCATION))
      errlongzero("CURLOPT_FOLLOWLOCATION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 22L);
      if(res && !bad_long(res, CURLOPT_FOLLOWLOCATION))
        errlong("CURLOPT_FOLLOWLOCATION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, LO);
      if(res && !bad_long(res, CURLOPT_FOLLOWLOCATION))
        errlong("CURLOPT_FOLLOWLOCATION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, HI);
      if(res && !bad_long(res, CURLOPT_FOLLOWLOCATION))
        errlong("CURLOPT_FOLLOWLOCATION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TRANSFERTEXT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TRANSFERTEXT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TRANSFERTEXT))
      errlongzero("CURLOPT_TRANSFERTEXT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TRANSFERTEXT, 22L);
      if(res && !bad_long(res, CURLOPT_TRANSFERTEXT))
        errlong("CURLOPT_TRANSFERTEXT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TRANSFERTEXT, LO);
      if(res && !bad_long(res, CURLOPT_TRANSFERTEXT))
        errlong("CURLOPT_TRANSFERTEXT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TRANSFERTEXT, HI);
      if(res && !bad_long(res, CURLOPT_TRANSFERTEXT))
        errlong("CURLOPT_TRANSFERTEXT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PUT))
      errlongzero("CURLOPT_PUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PUT, 22L);
      if(res && !bad_long(res, CURLOPT_PUT))
        errlong("CURLOPT_PUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PUT, LO);
      if(res && !bad_long(res, CURLOPT_PUT))
        errlong("CURLOPT_PUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PUT, HI);
      if(res && !bad_long(res, CURLOPT_PUT))
        errlong("CURLOPT_PUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROGRESSFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROGRESSFUNCTION,
                           progresscb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PROGRESSFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROGRESSFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_PROGRESSFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_XFERINFODATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_XFERINFODATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_XFERINFODATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_XFERINFODATA, NULL);
      if(res)
        errnull("CURLOPT_XFERINFODATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_AUTOREFERER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_AUTOREFERER, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_AUTOREFERER))
      errlongzero("CURLOPT_AUTOREFERER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_AUTOREFERER, 22L);
      if(res && !bad_long(res, CURLOPT_AUTOREFERER))
        errlong("CURLOPT_AUTOREFERER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_AUTOREFERER, LO);
      if(res && !bad_long(res, CURLOPT_AUTOREFERER))
        errlong("CURLOPT_AUTOREFERER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_AUTOREFERER, HI);
      if(res && !bad_long(res, CURLOPT_AUTOREFERER))
        errlong("CURLOPT_AUTOREFERER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYPORT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYPORT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXYPORT))
      errlongzero("CURLOPT_PROXYPORT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYPORT, 22L);
      if(res && !bad_long(res, CURLOPT_PROXYPORT))
        errlong("CURLOPT_PROXYPORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYPORT, LO);
      if(res && !bad_long(res, CURLOPT_PROXYPORT))
        errlong("CURLOPT_PROXYPORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYPORT, HI);
      if(res && !bad_long(res, CURLOPT_PROXYPORT))
        errlong("CURLOPT_PROXYPORT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POSTFIELDSIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_POSTFIELDSIZE))
      errlongzero("CURLOPT_POSTFIELDSIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 22L);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE))
        errlong("CURLOPT_POSTFIELDSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, LO);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE))
        errlong("CURLOPT_POSTFIELDSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, HI);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE))
        errlong("CURLOPT_POSTFIELDSIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTPPROXYTUNNEL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTPPROXYTUNNEL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTPPROXYTUNNEL))
      errlongzero("CURLOPT_HTTPPROXYTUNNEL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTPPROXYTUNNEL, 22L);
      if(res && !bad_long(res, CURLOPT_HTTPPROXYTUNNEL))
        errlong("CURLOPT_HTTPPROXYTUNNEL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPPROXYTUNNEL, LO);
      if(res && !bad_long(res, CURLOPT_HTTPPROXYTUNNEL))
        errlong("CURLOPT_HTTPPROXYTUNNEL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPPROXYTUNNEL, HI);
      if(res && !bad_long(res, CURLOPT_HTTPPROXYTUNNEL))
        errlong("CURLOPT_HTTPPROXYTUNNEL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_INTERFACE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_INTERFACE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_INTERFACE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_INTERFACE, NULL);
      if(res)
        errnull("CURLOPT_INTERFACE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_KRBLEVEL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_KRBLEVEL, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_KRBLEVEL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_KRBLEVEL, NULL);
      if(res)
        errnull("CURLOPT_KRBLEVEL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_VERIFYPEER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_VERIFYPEER))
      errlongzero("CURLOPT_SSL_VERIFYPEER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYPEER))
        errlong("CURLOPT_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, LO);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYPEER))
        errlong("CURLOPT_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, HI);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYPEER))
        errlong("CURLOPT_SSL_VERIFYPEER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CAINFO ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CAINFO, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_CAINFO", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CAINFO, NULL);
      if(res)
        errnull("CURLOPT_CAINFO", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXREDIRS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXREDIRS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXREDIRS))
      errlongzero("CURLOPT_MAXREDIRS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXREDIRS, 22L);
      if(res && !bad_long(res, CURLOPT_MAXREDIRS))
        errlong("CURLOPT_MAXREDIRS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXREDIRS, LO);
      if(res && !bad_long(res, CURLOPT_MAXREDIRS))
        errlong("CURLOPT_MAXREDIRS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXREDIRS, HI);
      if(res && !bad_long(res, CURLOPT_MAXREDIRS))
        errlong("CURLOPT_MAXREDIRS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FILETIME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FILETIME, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FILETIME))
      errlongzero("CURLOPT_FILETIME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FILETIME, 22L);
      if(res && !bad_long(res, CURLOPT_FILETIME))
        errlong("CURLOPT_FILETIME", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FILETIME, LO);
      if(res && !bad_long(res, CURLOPT_FILETIME))
        errlong("CURLOPT_FILETIME", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FILETIME, HI);
      if(res && !bad_long(res, CURLOPT_FILETIME))
        errlong("CURLOPT_FILETIME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TELNETOPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TELNETOPTIONS, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_TELNETOPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TELNETOPTIONS, NULL);
      if(res)
        errnull("CURLOPT_TELNETOPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXCONNECTS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXCONNECTS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXCONNECTS))
      errlongzero("CURLOPT_MAXCONNECTS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXCONNECTS, 22L);
      if(res && !bad_long(res, CURLOPT_MAXCONNECTS))
        errlong("CURLOPT_MAXCONNECTS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXCONNECTS, LO);
      if(res && !bad_long(res, CURLOPT_MAXCONNECTS))
        errlong("CURLOPT_MAXCONNECTS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXCONNECTS, HI);
      if(res && !bad_long(res, CURLOPT_MAXCONNECTS))
        errlong("CURLOPT_MAXCONNECTS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FRESH_CONNECT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FRESH_CONNECT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FRESH_CONNECT))
      errlongzero("CURLOPT_FRESH_CONNECT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FRESH_CONNECT, 22L);
      if(res && !bad_long(res, CURLOPT_FRESH_CONNECT))
        errlong("CURLOPT_FRESH_CONNECT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FRESH_CONNECT, LO);
      if(res && !bad_long(res, CURLOPT_FRESH_CONNECT))
        errlong("CURLOPT_FRESH_CONNECT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FRESH_CONNECT, HI);
      if(res && !bad_long(res, CURLOPT_FRESH_CONNECT))
        errlong("CURLOPT_FRESH_CONNECT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FORBID_REUSE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FORBID_REUSE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FORBID_REUSE))
      errlongzero("CURLOPT_FORBID_REUSE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FORBID_REUSE, 22L);
      if(res && !bad_long(res, CURLOPT_FORBID_REUSE))
        errlong("CURLOPT_FORBID_REUSE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FORBID_REUSE, LO);
      if(res && !bad_long(res, CURLOPT_FORBID_REUSE))
        errlong("CURLOPT_FORBID_REUSE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FORBID_REUSE, HI);
      if(res && !bad_long(res, CURLOPT_FORBID_REUSE))
        errlong("CURLOPT_FORBID_REUSE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RANDOM_FILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RANDOM_FILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_RANDOM_FILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RANDOM_FILE, NULL);
      if(res)
        errnull("CURLOPT_RANDOM_FILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_EGDSOCKET ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_EGDSOCKET, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_EGDSOCKET", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_EGDSOCKET, NULL);
      if(res)
        errnull("CURLOPT_EGDSOCKET", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONNECTTIMEOUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CONNECTTIMEOUT))
      errlongzero("CURLOPT_CONNECTTIMEOUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 22L);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT))
        errlong("CURLOPT_CONNECTTIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, LO);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT))
        errlong("CURLOPT_CONNECTTIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, HI);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT))
        errlong("CURLOPT_CONNECTTIMEOUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HEADERFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION,
                           headercb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HEADERFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_HEADERFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTPGET ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTPGET, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTPGET))
      errlongzero("CURLOPT_HTTPGET", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTPGET, 22L);
      if(res && !bad_long(res, CURLOPT_HTTPGET))
        errlong("CURLOPT_HTTPGET", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPGET, LO);
      if(res && !bad_long(res, CURLOPT_HTTPGET))
        errlong("CURLOPT_HTTPGET", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPGET, HI);
      if(res && !bad_long(res, CURLOPT_HTTPGET))
        errlong("CURLOPT_HTTPGET", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_VERIFYHOST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_VERIFYHOST))
      errlongzero("CURLOPT_SSL_VERIFYHOST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYHOST))
        errlong("CURLOPT_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, LO);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYHOST))
        errlong("CURLOPT_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, HI);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYHOST))
        errlong("CURLOPT_SSL_VERIFYHOST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COOKIEJAR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COOKIEJAR, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_COOKIEJAR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COOKIEJAR, NULL);
      if(res)
        errnull("CURLOPT_COOKIEJAR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_CIPHER_LIST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_CIPHER_LIST, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSL_CIPHER_LIST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_CIPHER_LIST, NULL);
      if(res)
        errnull("CURLOPT_SSL_CIPHER_LIST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTP_VERSION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTP_VERSION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTP_VERSION))
      errlongzero("CURLOPT_HTTP_VERSION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTP_VERSION, 22L);
      if(res && !bad_long(res, CURLOPT_HTTP_VERSION))
        errlong("CURLOPT_HTTP_VERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_VERSION, LO);
      if(res && !bad_long(res, CURLOPT_HTTP_VERSION))
        errlong("CURLOPT_HTTP_VERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_VERSION, HI);
      if(res && !bad_long(res, CURLOPT_HTTP_VERSION))
        errlong("CURLOPT_HTTP_VERSION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_USE_EPSV ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_USE_EPSV, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_USE_EPSV))
      errlongzero("CURLOPT_FTP_USE_EPSV", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPSV, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPSV))
        errlong("CURLOPT_FTP_USE_EPSV", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPSV, LO);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPSV))
        errlong("CURLOPT_FTP_USE_EPSV", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPSV, HI);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPSV))
        errlong("CURLOPT_FTP_USE_EPSV", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLCERTTYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLCERTTYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSLCERTTYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLCERTTYPE, NULL);
      if(res)
        errnull("CURLOPT_SSLCERTTYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLKEY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLKEY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSLKEY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLKEY, NULL);
      if(res)
        errnull("CURLOPT_SSLKEY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLKEYTYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLKEYTYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSLKEYTYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLKEYTYPE, NULL);
      if(res)
        errnull("CURLOPT_SSLKEYTYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLENGINE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLENGINE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSLENGINE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLENGINE, NULL);
      if(res)
        errnull("CURLOPT_SSLENGINE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLENGINE_DEFAULT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLENGINE_DEFAULT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSLENGINE_DEFAULT))
      errlongzero("CURLOPT_SSLENGINE_DEFAULT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLENGINE_DEFAULT, 22L);
      if(res && !bad_long(res, CURLOPT_SSLENGINE_DEFAULT))
        errlong("CURLOPT_SSLENGINE_DEFAULT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSLENGINE_DEFAULT, LO);
      if(res && !bad_long(res, CURLOPT_SSLENGINE_DEFAULT))
        errlong("CURLOPT_SSLENGINE_DEFAULT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSLENGINE_DEFAULT, HI);
      if(res && !bad_long(res, CURLOPT_SSLENGINE_DEFAULT))
        errlong("CURLOPT_SSLENGINE_DEFAULT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_USE_GLOBAL_CACHE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_USE_GLOBAL_CACHE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DNS_USE_GLOBAL_CACHE))
      errlongzero("CURLOPT_DNS_USE_GLOBAL_CACHE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_USE_GLOBAL_CACHE, 22L);
      if(res && !bad_long(res, CURLOPT_DNS_USE_GLOBAL_CACHE))
        errlong("CURLOPT_DNS_USE_GLOBAL_CACHE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_USE_GLOBAL_CACHE, LO);
      if(res && !bad_long(res, CURLOPT_DNS_USE_GLOBAL_CACHE))
        errlong("CURLOPT_DNS_USE_GLOBAL_CACHE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_USE_GLOBAL_CACHE, HI);
      if(res && !bad_long(res, CURLOPT_DNS_USE_GLOBAL_CACHE))
        errlong("CURLOPT_DNS_USE_GLOBAL_CACHE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_CACHE_TIMEOUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_CACHE_TIMEOUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DNS_CACHE_TIMEOUT))
      errlongzero("CURLOPT_DNS_CACHE_TIMEOUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_CACHE_TIMEOUT, 22L);
      if(res && !bad_long(res, CURLOPT_DNS_CACHE_TIMEOUT))
        errlong("CURLOPT_DNS_CACHE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_CACHE_TIMEOUT, LO);
      if(res && !bad_long(res, CURLOPT_DNS_CACHE_TIMEOUT))
        errlong("CURLOPT_DNS_CACHE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_CACHE_TIMEOUT, HI);
      if(res && !bad_long(res, CURLOPT_DNS_CACHE_TIMEOUT))
        errlong("CURLOPT_DNS_CACHE_TIMEOUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PREQUOTE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PREQUOTE, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PREQUOTE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PREQUOTE, NULL);
      if(res)
        errnull("CURLOPT_PREQUOTE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DEBUGFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DEBUGFUNCTION,
                           debugcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_DEBUGFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DEBUGFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_DEBUGFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DEBUGDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DEBUGDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_DEBUGDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DEBUGDATA, NULL);
      if(res)
        errnull("CURLOPT_DEBUGDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COOKIESESSION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COOKIESESSION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_COOKIESESSION))
      errlongzero("CURLOPT_COOKIESESSION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COOKIESESSION, 22L);
      if(res && !bad_long(res, CURLOPT_COOKIESESSION))
        errlong("CURLOPT_COOKIESESSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_COOKIESESSION, LO);
      if(res && !bad_long(res, CURLOPT_COOKIESESSION))
        errlong("CURLOPT_COOKIESESSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_COOKIESESSION, HI);
      if(res && !bad_long(res, CURLOPT_COOKIESESSION))
        errlong("CURLOPT_COOKIESESSION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CAPATH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CAPATH, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_CAPATH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CAPATH, NULL);
      if(res)
        errnull("CURLOPT_CAPATH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_BUFFERSIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_BUFFERSIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_BUFFERSIZE))
      errlongzero("CURLOPT_BUFFERSIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_BUFFERSIZE, 22L);
      if(res && !bad_long(res, CURLOPT_BUFFERSIZE))
        errlong("CURLOPT_BUFFERSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_BUFFERSIZE, LO);
      if(res && !bad_long(res, CURLOPT_BUFFERSIZE))
        errlong("CURLOPT_BUFFERSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_BUFFERSIZE, HI);
      if(res && !bad_long(res, CURLOPT_BUFFERSIZE))
        errlong("CURLOPT_BUFFERSIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NOSIGNAL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NOSIGNAL))
      errlongzero("CURLOPT_NOSIGNAL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 22L);
      if(res && !bad_long(res, CURLOPT_NOSIGNAL))
        errlong("CURLOPT_NOSIGNAL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOSIGNAL, LO);
      if(res && !bad_long(res, CURLOPT_NOSIGNAL))
        errlong("CURLOPT_NOSIGNAL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NOSIGNAL, HI);
      if(res && !bad_long(res, CURLOPT_NOSIGNAL))
        errlong("CURLOPT_NOSIGNAL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SHARE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SHARE, share);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SHARE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SHARE, NULL);
      if(res)
        errnull("CURLOPT_SHARE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYTYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYTYPE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXYTYPE))
      errlongzero("CURLOPT_PROXYTYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYTYPE, 22L);
      if(res && !bad_long(res, CURLOPT_PROXYTYPE))
        errlong("CURLOPT_PROXYTYPE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYTYPE, LO);
      if(res && !bad_long(res, CURLOPT_PROXYTYPE))
        errlong("CURLOPT_PROXYTYPE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYTYPE, HI);
      if(res && !bad_long(res, CURLOPT_PROXYTYPE))
        errlong("CURLOPT_PROXYTYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ACCEPT_ENCODING ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ACCEPT_ENCODING, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_ACCEPT_ENCODING", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ACCEPT_ENCODING, NULL);
      if(res)
        errnull("CURLOPT_ACCEPT_ENCODING", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PRIVATE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PRIVATE, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PRIVATE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PRIVATE, NULL);
      if(res)
        errnull("CURLOPT_PRIVATE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTP200ALIASES ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTP200ALIASES, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HTTP200ALIASES", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTP200ALIASES, NULL);
      if(res)
        errnull("CURLOPT_HTTP200ALIASES", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_UNRESTRICTED_AUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_UNRESTRICTED_AUTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_UNRESTRICTED_AUTH))
      errlongzero("CURLOPT_UNRESTRICTED_AUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_UNRESTRICTED_AUTH, 22L);
      if(res && !bad_long(res, CURLOPT_UNRESTRICTED_AUTH))
        errlong("CURLOPT_UNRESTRICTED_AUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UNRESTRICTED_AUTH, LO);
      if(res && !bad_long(res, CURLOPT_UNRESTRICTED_AUTH))
        errlong("CURLOPT_UNRESTRICTED_AUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UNRESTRICTED_AUTH, HI);
      if(res && !bad_long(res, CURLOPT_UNRESTRICTED_AUTH))
        errlong("CURLOPT_UNRESTRICTED_AUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_USE_EPRT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_USE_EPRT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_USE_EPRT))
      errlongzero("CURLOPT_FTP_USE_EPRT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPRT, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPRT))
        errlong("CURLOPT_FTP_USE_EPRT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPRT, LO);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPRT))
        errlong("CURLOPT_FTP_USE_EPRT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_EPRT, HI);
      if(res && !bad_long(res, CURLOPT_FTP_USE_EPRT))
        errlong("CURLOPT_FTP_USE_EPRT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTPAUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTPAUTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTPAUTH))
      errlongzero("CURLOPT_HTTPAUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTPAUTH, 22L);
      if(res && !bad_long(res, CURLOPT_HTTPAUTH))
        errlong("CURLOPT_HTTPAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPAUTH, LO);
      if(res && !bad_long(res, CURLOPT_HTTPAUTH))
        errlong("CURLOPT_HTTPAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTPAUTH, HI);
      if(res && !bad_long(res, CURLOPT_HTTPAUTH))
        errlong("CURLOPT_HTTPAUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_CTX_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_CTX_FUNCTION,
                           ssl_ctx_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSL_CTX_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_CTX_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_SSL_CTX_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_CTX_DATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_CTX_DATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSL_CTX_DATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_CTX_DATA, NULL);
      if(res)
        errnull("CURLOPT_SSL_CTX_DATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_CREATE_MISSING_DIRS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_CREATE_MISSING_DIRS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_CREATE_MISSING_DIRS))
      errlongzero("CURLOPT_FTP_CREATE_MISSING_DIRS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_CREATE_MISSING_DIRS, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_CREATE_MISSING_DIRS))
        errlong("CURLOPT_FTP_CREATE_MISSING_DIRS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_CREATE_MISSING_DIRS, LO);
      if(res && !bad_long(res, CURLOPT_FTP_CREATE_MISSING_DIRS))
        errlong("CURLOPT_FTP_CREATE_MISSING_DIRS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_CREATE_MISSING_DIRS, HI);
      if(res && !bad_long(res, CURLOPT_FTP_CREATE_MISSING_DIRS))
        errlong("CURLOPT_FTP_CREATE_MISSING_DIRS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYAUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYAUTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXYAUTH))
      errlongzero("CURLOPT_PROXYAUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYAUTH, 22L);
      if(res && !bad_long(res, CURLOPT_PROXYAUTH))
        errlong("CURLOPT_PROXYAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYAUTH, LO);
      if(res && !bad_long(res, CURLOPT_PROXYAUTH))
        errlong("CURLOPT_PROXYAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXYAUTH, HI);
      if(res && !bad_long(res, CURLOPT_PROXYAUTH))
        errlong("CURLOPT_PROXYAUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SERVER_RESPONSE_TIMEOUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SERVER_RESPONSE_TIMEOUT))
      errlongzero("CURLOPT_SERVER_RESPONSE_TIMEOUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT, 22L);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT, LO);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT, HI);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_IPRESOLVE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_IPRESOLVE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_IPRESOLVE))
      errlongzero("CURLOPT_IPRESOLVE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_IPRESOLVE, 22L);
      if(res && !bad_long(res, CURLOPT_IPRESOLVE))
        errlong("CURLOPT_IPRESOLVE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_IPRESOLVE, LO);
      if(res && !bad_long(res, CURLOPT_IPRESOLVE))
        errlong("CURLOPT_IPRESOLVE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_IPRESOLVE, HI);
      if(res && !bad_long(res, CURLOPT_IPRESOLVE))
        errlong("CURLOPT_IPRESOLVE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXFILESIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXFILESIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXFILESIZE))
      errlongzero("CURLOPT_MAXFILESIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE, 22L);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE))
        errlong("CURLOPT_MAXFILESIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE, LO);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE))
        errlong("CURLOPT_MAXFILESIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE, HI);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE))
        errlong("CURLOPT_MAXFILESIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_INFILESIZE_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_INFILESIZE_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_INFILESIZE_LARGE))
      errlongzero("CURLOPT_INFILESIZE_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_INFILESIZE_LARGE))
        errlong("CURLOPT_INFILESIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_INFILESIZE_LARGE))
        errlong("CURLOPT_INFILESIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_INFILESIZE_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_INFILESIZE_LARGE))
        errlong("CURLOPT_INFILESIZE_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RESUME_FROM_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RESUME_FROM_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_RESUME_FROM_LARGE))
      errlongzero("CURLOPT_RESUME_FROM_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM_LARGE))
        errlong("CURLOPT_RESUME_FROM_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM_LARGE))
        errlong("CURLOPT_RESUME_FROM_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RESUME_FROM_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_RESUME_FROM_LARGE))
        errlong("CURLOPT_RESUME_FROM_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXFILESIZE_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXFILESIZE_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXFILESIZE_LARGE))
      errlongzero("CURLOPT_MAXFILESIZE_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE_LARGE))
        errlong("CURLOPT_MAXFILESIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE_LARGE))
        errlong("CURLOPT_MAXFILESIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXFILESIZE_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_MAXFILESIZE_LARGE))
        errlong("CURLOPT_MAXFILESIZE_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NETRC_FILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NETRC_FILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_NETRC_FILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NETRC_FILE, NULL);
      if(res)
        errnull("CURLOPT_NETRC_FILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_USE_SSL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_USE_SSL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_USE_SSL))
      errlongzero("CURLOPT_USE_SSL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_USE_SSL, 22L);
      if(res && !bad_long(res, CURLOPT_USE_SSL))
        errlong("CURLOPT_USE_SSL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_USE_SSL, LO);
      if(res && !bad_long(res, CURLOPT_USE_SSL))
        errlong("CURLOPT_USE_SSL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_USE_SSL, HI);
      if(res && !bad_long(res, CURLOPT_USE_SSL))
        errlong("CURLOPT_USE_SSL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POSTFIELDSIZE_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_POSTFIELDSIZE_LARGE))
      errlongzero("CURLOPT_POSTFIELDSIZE_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE_LARGE))
        errlong("CURLOPT_POSTFIELDSIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE_LARGE))
        errlong("CURLOPT_POSTFIELDSIZE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_POSTFIELDSIZE_LARGE))
        errlong("CURLOPT_POSTFIELDSIZE_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_NODELAY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_NODELAY, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_NODELAY))
      errlongzero("CURLOPT_TCP_NODELAY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_NODELAY, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_NODELAY))
        errlong("CURLOPT_TCP_NODELAY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_NODELAY, LO);
      if(res && !bad_long(res, CURLOPT_TCP_NODELAY))
        errlong("CURLOPT_TCP_NODELAY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_NODELAY, HI);
      if(res && !bad_long(res, CURLOPT_TCP_NODELAY))
        errlong("CURLOPT_TCP_NODELAY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTPSSLAUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTPSSLAUTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTPSSLAUTH))
      errlongzero("CURLOPT_FTPSSLAUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTPSSLAUTH, 22L);
      if(res && !bad_long(res, CURLOPT_FTPSSLAUTH))
        errlong("CURLOPT_FTPSSLAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTPSSLAUTH, LO);
      if(res && !bad_long(res, CURLOPT_FTPSSLAUTH))
        errlong("CURLOPT_FTPSSLAUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTPSSLAUTH, HI);
      if(res && !bad_long(res, CURLOPT_FTPSSLAUTH))
        errlong("CURLOPT_FTPSSLAUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_IOCTLFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_IOCTLFUNCTION,
                           ioctlcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_IOCTLFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_IOCTLFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_IOCTLFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_IOCTLDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_IOCTLDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_IOCTLDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_IOCTLDATA, NULL);
      if(res)
        errnull("CURLOPT_IOCTLDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_ACCOUNT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_ACCOUNT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_FTP_ACCOUNT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_ACCOUNT, NULL);
      if(res)
        errnull("CURLOPT_FTP_ACCOUNT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COOKIELIST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COOKIELIST, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_COOKIELIST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COOKIELIST, NULL);
      if(res)
        errnull("CURLOPT_COOKIELIST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_IGNORE_CONTENT_LENGTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_IGNORE_CONTENT_LENGTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_IGNORE_CONTENT_LENGTH))
      errlongzero("CURLOPT_IGNORE_CONTENT_LENGTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_IGNORE_CONTENT_LENGTH, 22L);
      if(res && !bad_long(res, CURLOPT_IGNORE_CONTENT_LENGTH))
        errlong("CURLOPT_IGNORE_CONTENT_LENGTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_IGNORE_CONTENT_LENGTH, LO);
      if(res && !bad_long(res, CURLOPT_IGNORE_CONTENT_LENGTH))
        errlong("CURLOPT_IGNORE_CONTENT_LENGTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_IGNORE_CONTENT_LENGTH, HI);
      if(res && !bad_long(res, CURLOPT_IGNORE_CONTENT_LENGTH))
        errlong("CURLOPT_IGNORE_CONTENT_LENGTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_SKIP_PASV_IP ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_SKIP_PASV_IP, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_SKIP_PASV_IP))
      errlongzero("CURLOPT_FTP_SKIP_PASV_IP", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_SKIP_PASV_IP, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_SKIP_PASV_IP))
        errlong("CURLOPT_FTP_SKIP_PASV_IP", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_SKIP_PASV_IP, LO);
      if(res && !bad_long(res, CURLOPT_FTP_SKIP_PASV_IP))
        errlong("CURLOPT_FTP_SKIP_PASV_IP", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_SKIP_PASV_IP, HI);
      if(res && !bad_long(res, CURLOPT_FTP_SKIP_PASV_IP))
        errlong("CURLOPT_FTP_SKIP_PASV_IP", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_FILEMETHOD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_FILEMETHOD, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_FILEMETHOD))
      errlongzero("CURLOPT_FTP_FILEMETHOD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_FILEMETHOD, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_FILEMETHOD))
        errlong("CURLOPT_FTP_FILEMETHOD", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_FILEMETHOD, LO);
      if(res && !bad_long(res, CURLOPT_FTP_FILEMETHOD))
        errlong("CURLOPT_FTP_FILEMETHOD", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_FILEMETHOD, HI);
      if(res && !bad_long(res, CURLOPT_FTP_FILEMETHOD))
        errlong("CURLOPT_FTP_FILEMETHOD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_LOCALPORT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_LOCALPORT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_LOCALPORT))
      errlongzero("CURLOPT_LOCALPORT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORT, 22L);
      if(res && !bad_long(res, CURLOPT_LOCALPORT))
        errlong("CURLOPT_LOCALPORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORT, LO);
      if(res && !bad_long(res, CURLOPT_LOCALPORT))
        errlong("CURLOPT_LOCALPORT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORT, HI);
      if(res && !bad_long(res, CURLOPT_LOCALPORT))
        errlong("CURLOPT_LOCALPORT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_LOCALPORTRANGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_LOCALPORTRANGE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_LOCALPORTRANGE))
      errlongzero("CURLOPT_LOCALPORTRANGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORTRANGE, 22L);
      if(res && !bad_long(res, CURLOPT_LOCALPORTRANGE))
        errlong("CURLOPT_LOCALPORTRANGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORTRANGE, LO);
      if(res && !bad_long(res, CURLOPT_LOCALPORTRANGE))
        errlong("CURLOPT_LOCALPORTRANGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_LOCALPORTRANGE, HI);
      if(res && !bad_long(res, CURLOPT_LOCALPORTRANGE))
        errlong("CURLOPT_LOCALPORTRANGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONNECT_ONLY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONNECT_ONLY, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CONNECT_ONLY))
      errlongzero("CURLOPT_CONNECT_ONLY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONNECT_ONLY, 22L);
      if(res && !bad_long(res, CURLOPT_CONNECT_ONLY))
        errlong("CURLOPT_CONNECT_ONLY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECT_ONLY, LO);
      if(res && !bad_long(res, CURLOPT_CONNECT_ONLY))
        errlong("CURLOPT_CONNECT_ONLY", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECT_ONLY, HI);
      if(res && !bad_long(res, CURLOPT_CONNECT_ONLY))
        errlong("CURLOPT_CONNECT_ONLY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONV_FROM_NETWORK_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONV_FROM_NETWORK_FUNCTION,
                           conv_from_network_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CONV_FROM_NETWORK_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONV_FROM_NETWORK_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CONV_FROM_NETWORK_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONV_TO_NETWORK_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONV_TO_NETWORK_FUNCTION,
                           conv_to_network_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CONV_TO_NETWORK_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONV_TO_NETWORK_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CONV_TO_NETWORK_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONV_FROM_UTF8_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONV_FROM_UTF8_FUNCTION,
                           conv_from_utf8_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CONV_FROM_UTF8_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONV_FROM_UTF8_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CONV_FROM_UTF8_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAX_SEND_SPEED_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAX_SEND_SPEED_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAX_SEND_SPEED_LARGE))
      errlongzero("CURLOPT_MAX_SEND_SPEED_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAX_SEND_SPEED_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_MAX_SEND_SPEED_LARGE))
        errlong("CURLOPT_MAX_SEND_SPEED_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAX_SEND_SPEED_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_MAX_SEND_SPEED_LARGE))
        errlong("CURLOPT_MAX_SEND_SPEED_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAX_SEND_SPEED_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_MAX_SEND_SPEED_LARGE))
        errlong("CURLOPT_MAX_SEND_SPEED_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAX_RECV_SPEED_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAX_RECV_SPEED_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAX_RECV_SPEED_LARGE))
      errlongzero("CURLOPT_MAX_RECV_SPEED_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAX_RECV_SPEED_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_MAX_RECV_SPEED_LARGE))
        errlong("CURLOPT_MAX_RECV_SPEED_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAX_RECV_SPEED_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_MAX_RECV_SPEED_LARGE))
        errlong("CURLOPT_MAX_RECV_SPEED_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAX_RECV_SPEED_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_MAX_RECV_SPEED_LARGE))
        errlong("CURLOPT_MAX_RECV_SPEED_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_ALTERNATIVE_TO_USER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_ALTERNATIVE_TO_USER, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_FTP_ALTERNATIVE_TO_USER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_ALTERNATIVE_TO_USER, NULL);
      if(res)
        errnull("CURLOPT_FTP_ALTERNATIVE_TO_USER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SOCKOPTFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SOCKOPTFUNCTION,
                           sockoptcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SOCKOPTFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SOCKOPTFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_SOCKOPTFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SOCKOPTDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SOCKOPTDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SOCKOPTDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SOCKOPTDATA, NULL);
      if(res)
        errnull("CURLOPT_SOCKOPTDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_SESSIONID_CACHE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_SESSIONID_CACHE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_SESSIONID_CACHE))
      errlongzero("CURLOPT_SSL_SESSIONID_CACHE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_SESSIONID_CACHE, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_SESSIONID_CACHE))
        errlong("CURLOPT_SSL_SESSIONID_CACHE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_SESSIONID_CACHE, LO);
      if(res && !bad_long(res, CURLOPT_SSL_SESSIONID_CACHE))
        errlong("CURLOPT_SSL_SESSIONID_CACHE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_SESSIONID_CACHE, HI);
      if(res && !bad_long(res, CURLOPT_SSL_SESSIONID_CACHE))
        errlong("CURLOPT_SSL_SESSIONID_CACHE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_AUTH_TYPES ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_AUTH_TYPES, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSH_AUTH_TYPES))
      errlongzero("CURLOPT_SSH_AUTH_TYPES", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_AUTH_TYPES, 22L);
      if(res && !bad_long(res, CURLOPT_SSH_AUTH_TYPES))
        errlong("CURLOPT_SSH_AUTH_TYPES", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSH_AUTH_TYPES, LO);
      if(res && !bad_long(res, CURLOPT_SSH_AUTH_TYPES))
        errlong("CURLOPT_SSH_AUTH_TYPES", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSH_AUTH_TYPES, HI);
      if(res && !bad_long(res, CURLOPT_SSH_AUTH_TYPES))
        errlong("CURLOPT_SSH_AUTH_TYPES", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_PUBLIC_KEYFILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_PUBLIC_KEYFILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSH_PUBLIC_KEYFILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_PUBLIC_KEYFILE, NULL);
      if(res)
        errnull("CURLOPT_SSH_PUBLIC_KEYFILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_PRIVATE_KEYFILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_PRIVATE_KEYFILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSH_PRIVATE_KEYFILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_PRIVATE_KEYFILE, NULL);
      if(res)
        errnull("CURLOPT_SSH_PRIVATE_KEYFILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_SSL_CCC ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_SSL_CCC, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_SSL_CCC))
      errlongzero("CURLOPT_FTP_SSL_CCC", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_SSL_CCC, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_SSL_CCC))
        errlong("CURLOPT_FTP_SSL_CCC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_SSL_CCC, LO);
      if(res && !bad_long(res, CURLOPT_FTP_SSL_CCC))
        errlong("CURLOPT_FTP_SSL_CCC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_SSL_CCC, HI);
      if(res && !bad_long(res, CURLOPT_FTP_SSL_CCC))
        errlong("CURLOPT_FTP_SSL_CCC", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TIMEOUT_MS))
      errlongzero("CURLOPT_TIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_TIMEOUT_MS))
        errlong("CURLOPT_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_TIMEOUT_MS))
        errlong("CURLOPT_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_TIMEOUT_MS))
        errlong("CURLOPT_TIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONNECTTIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CONNECTTIMEOUT_MS))
      errlongzero("CURLOPT_CONNECTTIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT_MS))
        errlong("CURLOPT_CONNECTTIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT_MS))
        errlong("CURLOPT_CONNECTTIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_CONNECTTIMEOUT_MS))
        errlong("CURLOPT_CONNECTTIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTP_TRANSFER_DECODING ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTP_TRANSFER_DECODING, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTP_TRANSFER_DECODING))
      errlongzero("CURLOPT_HTTP_TRANSFER_DECODING", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTP_TRANSFER_DECODING, 22L);
      if(res && !bad_long(res, CURLOPT_HTTP_TRANSFER_DECODING))
        errlong("CURLOPT_HTTP_TRANSFER_DECODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_TRANSFER_DECODING, LO);
      if(res && !bad_long(res, CURLOPT_HTTP_TRANSFER_DECODING))
        errlong("CURLOPT_HTTP_TRANSFER_DECODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_TRANSFER_DECODING, HI);
      if(res && !bad_long(res, CURLOPT_HTTP_TRANSFER_DECODING))
        errlong("CURLOPT_HTTP_TRANSFER_DECODING", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTP_CONTENT_DECODING ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTP_CONTENT_DECODING, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTP_CONTENT_DECODING))
      errlongzero("CURLOPT_HTTP_CONTENT_DECODING", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTP_CONTENT_DECODING, 22L);
      if(res && !bad_long(res, CURLOPT_HTTP_CONTENT_DECODING))
        errlong("CURLOPT_HTTP_CONTENT_DECODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_CONTENT_DECODING, LO);
      if(res && !bad_long(res, CURLOPT_HTTP_CONTENT_DECODING))
        errlong("CURLOPT_HTTP_CONTENT_DECODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP_CONTENT_DECODING, HI);
      if(res && !bad_long(res, CURLOPT_HTTP_CONTENT_DECODING))
        errlong("CURLOPT_HTTP_CONTENT_DECODING", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NEW_FILE_PERMS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NEW_FILE_PERMS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NEW_FILE_PERMS))
      errlongzero("CURLOPT_NEW_FILE_PERMS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NEW_FILE_PERMS, 22L);
      if(res && !bad_long(res, CURLOPT_NEW_FILE_PERMS))
        errlong("CURLOPT_NEW_FILE_PERMS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NEW_FILE_PERMS, LO);
      if(res && !bad_long(res, CURLOPT_NEW_FILE_PERMS))
        errlong("CURLOPT_NEW_FILE_PERMS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NEW_FILE_PERMS, HI);
      if(res && !bad_long(res, CURLOPT_NEW_FILE_PERMS))
        errlong("CURLOPT_NEW_FILE_PERMS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NEW_DIRECTORY_PERMS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NEW_DIRECTORY_PERMS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_NEW_DIRECTORY_PERMS))
      errlongzero("CURLOPT_NEW_DIRECTORY_PERMS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NEW_DIRECTORY_PERMS, 22L);
      if(res && !bad_long(res, CURLOPT_NEW_DIRECTORY_PERMS))
        errlong("CURLOPT_NEW_DIRECTORY_PERMS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NEW_DIRECTORY_PERMS, LO);
      if(res && !bad_long(res, CURLOPT_NEW_DIRECTORY_PERMS))
        errlong("CURLOPT_NEW_DIRECTORY_PERMS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_NEW_DIRECTORY_PERMS, HI);
      if(res && !bad_long(res, CURLOPT_NEW_DIRECTORY_PERMS))
        errlong("CURLOPT_NEW_DIRECTORY_PERMS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_POSTREDIR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_POSTREDIR, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_POSTREDIR))
      errlongzero("CURLOPT_POSTREDIR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_POSTREDIR, 22L);
      if(res && !bad_long(res, CURLOPT_POSTREDIR))
        errlong("CURLOPT_POSTREDIR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTREDIR, LO);
      if(res && !bad_long(res, CURLOPT_POSTREDIR))
        errlong("CURLOPT_POSTREDIR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_POSTREDIR, HI);
      if(res && !bad_long(res, CURLOPT_POSTREDIR))
        errlong("CURLOPT_POSTREDIR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_HOST_PUBLIC_KEY_MD5 ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_HOST_PUBLIC_KEY_MD5, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSH_HOST_PUBLIC_KEY_MD5", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_HOST_PUBLIC_KEY_MD5, NULL);
      if(res)
        errnull("CURLOPT_SSH_HOST_PUBLIC_KEY_MD5", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_OPENSOCKETFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_OPENSOCKETFUNCTION,
                           opensocketcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_OPENSOCKETFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_OPENSOCKETFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_OPENSOCKETFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_OPENSOCKETDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_OPENSOCKETDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_OPENSOCKETDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_OPENSOCKETDATA, NULL);
      if(res)
        errnull("CURLOPT_OPENSOCKETDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_COPYPOSTFIELDS ******/
  (void)curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 0);
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_COPYPOSTFIELDS, stringpointerextra);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_COPYPOSTFIELDS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_COPYPOSTFIELDS, NULL);
      if(res)
        errnull("CURLOPT_COPYPOSTFIELDS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_TRANSFER_MODE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXY_TRANSFER_MODE))
      errlongzero("CURLOPT_PROXY_TRANSFER_MODE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, 22L);
      if(res && !bad_long(res, CURLOPT_PROXY_TRANSFER_MODE))
        errlong("CURLOPT_PROXY_TRANSFER_MODE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, LO);
      if(res && !bad_long(res, CURLOPT_PROXY_TRANSFER_MODE))
        errlong("CURLOPT_PROXY_TRANSFER_MODE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, HI);
      if(res && !bad_long(res, CURLOPT_PROXY_TRANSFER_MODE))
        errlong("CURLOPT_PROXY_TRANSFER_MODE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SEEKFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SEEKFUNCTION,
                           seekcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SEEKFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SEEKFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_SEEKFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SEEKDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SEEKDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SEEKDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SEEKDATA, NULL);
      if(res)
        errnull("CURLOPT_SEEKDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CRLFILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CRLFILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_CRLFILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CRLFILE, NULL);
      if(res)
        errnull("CURLOPT_CRLFILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ISSUERCERT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ISSUERCERT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_ISSUERCERT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ISSUERCERT, NULL);
      if(res)
        errnull("CURLOPT_ISSUERCERT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ADDRESS_SCOPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ADDRESS_SCOPE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_ADDRESS_SCOPE))
      errlongzero("CURLOPT_ADDRESS_SCOPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ADDRESS_SCOPE, 22L);
      if(res && !bad_long(res, CURLOPT_ADDRESS_SCOPE))
        errlong("CURLOPT_ADDRESS_SCOPE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ADDRESS_SCOPE, LO);
      if(res && !bad_long(res, CURLOPT_ADDRESS_SCOPE))
        errlong("CURLOPT_ADDRESS_SCOPE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ADDRESS_SCOPE, HI);
      if(res && !bad_long(res, CURLOPT_ADDRESS_SCOPE))
        errlong("CURLOPT_ADDRESS_SCOPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CERTINFO ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CERTINFO, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CERTINFO))
      errlongzero("CURLOPT_CERTINFO", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CERTINFO, 22L);
      if(res && !bad_long(res, CURLOPT_CERTINFO))
        errlong("CURLOPT_CERTINFO", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CERTINFO, LO);
      if(res && !bad_long(res, CURLOPT_CERTINFO))
        errlong("CURLOPT_CERTINFO", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CERTINFO, HI);
      if(res && !bad_long(res, CURLOPT_CERTINFO))
        errlong("CURLOPT_CERTINFO", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_USERNAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_USERNAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_USERNAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_USERNAME, NULL);
      if(res)
        errnull("CURLOPT_USERNAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PASSWORD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PASSWORD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PASSWORD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PASSWORD, NULL);
      if(res)
        errnull("CURLOPT_PASSWORD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYUSERNAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXYUSERNAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYUSERNAME, NULL);
      if(res)
        errnull("CURLOPT_PROXYUSERNAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYPASSWORD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXYPASSWORD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYPASSWORD, NULL);
      if(res)
        errnull("CURLOPT_PROXYPASSWORD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_NOPROXY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_NOPROXY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_NOPROXY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_NOPROXY, NULL);
      if(res)
        errnull("CURLOPT_NOPROXY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TFTP_BLKSIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TFTP_BLKSIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TFTP_BLKSIZE))
      errlongzero("CURLOPT_TFTP_BLKSIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TFTP_BLKSIZE, 22L);
      if(res && !bad_long(res, CURLOPT_TFTP_BLKSIZE))
        errlong("CURLOPT_TFTP_BLKSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TFTP_BLKSIZE, LO);
      if(res && !bad_long(res, CURLOPT_TFTP_BLKSIZE))
        errlong("CURLOPT_TFTP_BLKSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TFTP_BLKSIZE, HI);
      if(res && !bad_long(res, CURLOPT_TFTP_BLKSIZE))
        errlong("CURLOPT_TFTP_BLKSIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SOCKS5_GSSAPI_SERVICE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_SERVICE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SOCKS5_GSSAPI_SERVICE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_SERVICE, NULL);
      if(res)
        errnull("CURLOPT_SOCKS5_GSSAPI_SERVICE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SOCKS5_GSSAPI_NEC ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_NEC, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SOCKS5_GSSAPI_NEC))
      errlongzero("CURLOPT_SOCKS5_GSSAPI_NEC", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_NEC, 22L);
      if(res && !bad_long(res, CURLOPT_SOCKS5_GSSAPI_NEC))
        errlong("CURLOPT_SOCKS5_GSSAPI_NEC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_NEC, LO);
      if(res && !bad_long(res, CURLOPT_SOCKS5_GSSAPI_NEC))
        errlong("CURLOPT_SOCKS5_GSSAPI_NEC", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_GSSAPI_NEC, HI);
      if(res && !bad_long(res, CURLOPT_SOCKS5_GSSAPI_NEC))
        errlong("CURLOPT_SOCKS5_GSSAPI_NEC", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROTOCOLS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROTOCOLS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROTOCOLS))
      errlongzero("CURLOPT_PROTOCOLS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROTOCOLS, 22L);
      if(res && !bad_long(res, CURLOPT_PROTOCOLS))
        errlong("CURLOPT_PROTOCOLS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROTOCOLS, LO);
      if(res && !bad_long(res, CURLOPT_PROTOCOLS))
        errlong("CURLOPT_PROTOCOLS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROTOCOLS, HI);
      if(res && !bad_long(res, CURLOPT_PROTOCOLS))
        errlong("CURLOPT_PROTOCOLS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_REDIR_PROTOCOLS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_REDIR_PROTOCOLS))
      errlongzero("CURLOPT_REDIR_PROTOCOLS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS, 22L);
      if(res && !bad_long(res, CURLOPT_REDIR_PROTOCOLS))
        errlong("CURLOPT_REDIR_PROTOCOLS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS, LO);
      if(res && !bad_long(res, CURLOPT_REDIR_PROTOCOLS))
        errlong("CURLOPT_REDIR_PROTOCOLS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS, HI);
      if(res && !bad_long(res, CURLOPT_REDIR_PROTOCOLS))
        errlong("CURLOPT_REDIR_PROTOCOLS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_KNOWNHOSTS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_KNOWNHOSTS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSH_KNOWNHOSTS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_KNOWNHOSTS, NULL);
      if(res)
        errnull("CURLOPT_SSH_KNOWNHOSTS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_KEYFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_KEYFUNCTION,
                           ssh_keycb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSH_KEYFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_KEYFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_SSH_KEYFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_KEYDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_KEYDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSH_KEYDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_KEYDATA, NULL);
      if(res)
        errnull("CURLOPT_SSH_KEYDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAIL_FROM ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAIL_FROM, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_MAIL_FROM", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAIL_FROM, NULL);
      if(res)
        errnull("CURLOPT_MAIL_FROM", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAIL_RCPT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAIL_RCPT, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_MAIL_RCPT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAIL_RCPT, NULL);
      if(res)
        errnull("CURLOPT_MAIL_RCPT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FTP_USE_PRET ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FTP_USE_PRET, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_FTP_USE_PRET))
      errlongzero("CURLOPT_FTP_USE_PRET", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_PRET, 22L);
      if(res && !bad_long(res, CURLOPT_FTP_USE_PRET))
        errlong("CURLOPT_FTP_USE_PRET", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_PRET, LO);
      if(res && !bad_long(res, CURLOPT_FTP_USE_PRET))
        errlong("CURLOPT_FTP_USE_PRET", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_FTP_USE_PRET, HI);
      if(res && !bad_long(res, CURLOPT_FTP_USE_PRET))
        errlong("CURLOPT_FTP_USE_PRET", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_REQUEST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_REQUEST, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_RTSP_REQUEST))
      errlongzero("CURLOPT_RTSP_REQUEST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_REQUEST, 22L);
      if(res && !bad_long(res, CURLOPT_RTSP_REQUEST))
        errlong("CURLOPT_RTSP_REQUEST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_REQUEST, LO);
      if(res && !bad_long(res, CURLOPT_RTSP_REQUEST))
        errlong("CURLOPT_RTSP_REQUEST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_REQUEST, HI);
      if(res && !bad_long(res, CURLOPT_RTSP_REQUEST))
        errlong("CURLOPT_RTSP_REQUEST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_SESSION_ID ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_SESSION_ID, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_RTSP_SESSION_ID", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_SESSION_ID, NULL);
      if(res)
        errnull("CURLOPT_RTSP_SESSION_ID", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_STREAM_URI ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_STREAM_URI, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_RTSP_STREAM_URI", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_STREAM_URI, NULL);
      if(res)
        errnull("CURLOPT_RTSP_STREAM_URI", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_TRANSPORT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_TRANSPORT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_RTSP_TRANSPORT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_TRANSPORT, NULL);
      if(res)
        errnull("CURLOPT_RTSP_TRANSPORT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_CLIENT_CSEQ ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_CLIENT_CSEQ, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_RTSP_CLIENT_CSEQ))
      errlongzero("CURLOPT_RTSP_CLIENT_CSEQ", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_CLIENT_CSEQ, 22L);
      if(res && !bad_long(res, CURLOPT_RTSP_CLIENT_CSEQ))
        errlong("CURLOPT_RTSP_CLIENT_CSEQ", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_CLIENT_CSEQ, LO);
      if(res && !bad_long(res, CURLOPT_RTSP_CLIENT_CSEQ))
        errlong("CURLOPT_RTSP_CLIENT_CSEQ", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_CLIENT_CSEQ, HI);
      if(res && !bad_long(res, CURLOPT_RTSP_CLIENT_CSEQ))
        errlong("CURLOPT_RTSP_CLIENT_CSEQ", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RTSP_SERVER_CSEQ ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RTSP_SERVER_CSEQ, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_RTSP_SERVER_CSEQ))
      errlongzero("CURLOPT_RTSP_SERVER_CSEQ", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RTSP_SERVER_CSEQ, 22L);
      if(res && !bad_long(res, CURLOPT_RTSP_SERVER_CSEQ))
        errlong("CURLOPT_RTSP_SERVER_CSEQ", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_SERVER_CSEQ, LO);
      if(res && !bad_long(res, CURLOPT_RTSP_SERVER_CSEQ))
        errlong("CURLOPT_RTSP_SERVER_CSEQ", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_RTSP_SERVER_CSEQ, HI);
      if(res && !bad_long(res, CURLOPT_RTSP_SERVER_CSEQ))
        errlong("CURLOPT_RTSP_SERVER_CSEQ", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_INTERLEAVEDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_INTERLEAVEDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_INTERLEAVEDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_INTERLEAVEDATA, NULL);
      if(res)
        errnull("CURLOPT_INTERLEAVEDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_INTERLEAVEFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_INTERLEAVEFUNCTION,
                           interleavecb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_INTERLEAVEFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_INTERLEAVEFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_INTERLEAVEFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_WILDCARDMATCH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_WILDCARDMATCH))
      errlongzero("CURLOPT_WILDCARDMATCH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, 22L);
      if(res && !bad_long(res, CURLOPT_WILDCARDMATCH))
        errlong("CURLOPT_WILDCARDMATCH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, LO);
      if(res && !bad_long(res, CURLOPT_WILDCARDMATCH))
        errlong("CURLOPT_WILDCARDMATCH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_WILDCARDMATCH, HI);
      if(res && !bad_long(res, CURLOPT_WILDCARDMATCH))
        errlong("CURLOPT_WILDCARDMATCH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CHUNK_BGN_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CHUNK_BGN_FUNCTION,
                           chunk_bgn_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CHUNK_BGN_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CHUNK_BGN_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CHUNK_BGN_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CHUNK_END_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CHUNK_END_FUNCTION,
                           chunk_end_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CHUNK_END_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CHUNK_END_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CHUNK_END_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FNMATCH_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FNMATCH_FUNCTION,
                           fnmatch_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_FNMATCH_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FNMATCH_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_FNMATCH_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CHUNK_DATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CHUNK_DATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CHUNK_DATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CHUNK_DATA, NULL);
      if(res)
        errnull("CURLOPT_CHUNK_DATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_FNMATCH_DATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_FNMATCH_DATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_FNMATCH_DATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_FNMATCH_DATA, NULL);
      if(res)
        errnull("CURLOPT_FNMATCH_DATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RESOLVE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RESOLVE, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_RESOLVE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RESOLVE, NULL);
      if(res)
        errnull("CURLOPT_RESOLVE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TLSAUTH_USERNAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TLSAUTH_USERNAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_TLSAUTH_USERNAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TLSAUTH_USERNAME, NULL);
      if(res)
        errnull("CURLOPT_TLSAUTH_USERNAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TLSAUTH_PASSWORD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TLSAUTH_PASSWORD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_TLSAUTH_PASSWORD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TLSAUTH_PASSWORD, NULL);
      if(res)
        errnull("CURLOPT_TLSAUTH_PASSWORD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TLSAUTH_TYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TLSAUTH_TYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_TLSAUTH_TYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TLSAUTH_TYPE, NULL);
      if(res)
        errnull("CURLOPT_TLSAUTH_TYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TRANSFER_ENCODING ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TRANSFER_ENCODING, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TRANSFER_ENCODING))
      errlongzero("CURLOPT_TRANSFER_ENCODING", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TRANSFER_ENCODING, 22L);
      if(res && !bad_long(res, CURLOPT_TRANSFER_ENCODING))
        errlong("CURLOPT_TRANSFER_ENCODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TRANSFER_ENCODING, LO);
      if(res && !bad_long(res, CURLOPT_TRANSFER_ENCODING))
        errlong("CURLOPT_TRANSFER_ENCODING", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TRANSFER_ENCODING, HI);
      if(res && !bad_long(res, CURLOPT_TRANSFER_ENCODING))
        errlong("CURLOPT_TRANSFER_ENCODING", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CLOSESOCKETFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CLOSESOCKETFUNCTION,
                           closesocketcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CLOSESOCKETFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CLOSESOCKETFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_CLOSESOCKETFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CLOSESOCKETDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CLOSESOCKETDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CLOSESOCKETDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CLOSESOCKETDATA, NULL);
      if(res)
        errnull("CURLOPT_CLOSESOCKETDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_GSSAPI_DELEGATION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_GSSAPI_DELEGATION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_GSSAPI_DELEGATION))
      errlongzero("CURLOPT_GSSAPI_DELEGATION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_GSSAPI_DELEGATION, 22L);
      if(res && !bad_long(res, CURLOPT_GSSAPI_DELEGATION))
        errlong("CURLOPT_GSSAPI_DELEGATION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_GSSAPI_DELEGATION, LO);
      if(res && !bad_long(res, CURLOPT_GSSAPI_DELEGATION))
        errlong("CURLOPT_GSSAPI_DELEGATION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_GSSAPI_DELEGATION, HI);
      if(res && !bad_long(res, CURLOPT_GSSAPI_DELEGATION))
        errlong("CURLOPT_GSSAPI_DELEGATION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_SERVERS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_SERVERS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DNS_SERVERS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_SERVERS, NULL);
      if(res)
        errnull("CURLOPT_DNS_SERVERS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ACCEPTTIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ACCEPTTIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_ACCEPTTIMEOUT_MS))
      errlongzero("CURLOPT_ACCEPTTIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ACCEPTTIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_ACCEPTTIMEOUT_MS))
        errlong("CURLOPT_ACCEPTTIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ACCEPTTIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_ACCEPTTIMEOUT_MS))
        errlong("CURLOPT_ACCEPTTIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ACCEPTTIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_ACCEPTTIMEOUT_MS))
        errlong("CURLOPT_ACCEPTTIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_KEEPALIVE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_KEEPALIVE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_KEEPALIVE))
      errlongzero("CURLOPT_TCP_KEEPALIVE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPALIVE, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPALIVE))
        errlong("CURLOPT_TCP_KEEPALIVE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPALIVE, LO);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPALIVE))
        errlong("CURLOPT_TCP_KEEPALIVE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPALIVE, HI);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPALIVE))
        errlong("CURLOPT_TCP_KEEPALIVE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_KEEPIDLE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_KEEPIDLE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_KEEPIDLE))
      errlongzero("CURLOPT_TCP_KEEPIDLE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPIDLE, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPIDLE))
        errlong("CURLOPT_TCP_KEEPIDLE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPIDLE, LO);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPIDLE))
        errlong("CURLOPT_TCP_KEEPIDLE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPIDLE, HI);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPIDLE))
        errlong("CURLOPT_TCP_KEEPIDLE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_KEEPINTVL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_KEEPINTVL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_KEEPINTVL))
      errlongzero("CURLOPT_TCP_KEEPINTVL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPINTVL, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPINTVL))
        errlong("CURLOPT_TCP_KEEPINTVL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPINTVL, LO);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPINTVL))
        errlong("CURLOPT_TCP_KEEPINTVL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPINTVL, HI);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPINTVL))
        errlong("CURLOPT_TCP_KEEPINTVL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_OPTIONS))
      errlongzero("CURLOPT_SSL_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_OPTIONS))
        errlong("CURLOPT_SSL_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, LO);
      if(res && !bad_long(res, CURLOPT_SSL_OPTIONS))
        errlong("CURLOPT_SSL_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_OPTIONS, HI);
      if(res && !bad_long(res, CURLOPT_SSL_OPTIONS))
        errlong("CURLOPT_SSL_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAIL_AUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAIL_AUTH, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_MAIL_AUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAIL_AUTH, NULL);
      if(res)
        errnull("CURLOPT_MAIL_AUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SASL_IR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SASL_IR, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SASL_IR))
      errlongzero("CURLOPT_SASL_IR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SASL_IR, 22L);
      if(res && !bad_long(res, CURLOPT_SASL_IR))
        errlong("CURLOPT_SASL_IR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SASL_IR, LO);
      if(res && !bad_long(res, CURLOPT_SASL_IR))
        errlong("CURLOPT_SASL_IR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SASL_IR, HI);
      if(res && !bad_long(res, CURLOPT_SASL_IR))
        errlong("CURLOPT_SASL_IR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_XFERINFOFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_XFERINFOFUNCTION,
                           xferinfocb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_XFERINFOFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_XFERINFOFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_XFERINFOFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_XOAUTH2_BEARER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_XOAUTH2_BEARER, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_XOAUTH2_BEARER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_XOAUTH2_BEARER, NULL);
      if(res)
        errnull("CURLOPT_XOAUTH2_BEARER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_INTERFACE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_INTERFACE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DNS_INTERFACE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_INTERFACE, NULL);
      if(res)
        errnull("CURLOPT_DNS_INTERFACE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_LOCAL_IP4 ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_LOCAL_IP4, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DNS_LOCAL_IP4", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_LOCAL_IP4, NULL);
      if(res)
        errnull("CURLOPT_DNS_LOCAL_IP4", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_LOCAL_IP6 ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_LOCAL_IP6, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DNS_LOCAL_IP6", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_LOCAL_IP6, NULL);
      if(res)
        errnull("CURLOPT_DNS_LOCAL_IP6", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_LOGIN_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_LOGIN_OPTIONS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_LOGIN_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_LOGIN_OPTIONS, NULL);
      if(res)
        errnull("CURLOPT_LOGIN_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_ENABLE_NPN ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_NPN, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_ENABLE_NPN))
      errlongzero("CURLOPT_SSL_ENABLE_NPN", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_NPN, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_NPN))
        errlong("CURLOPT_SSL_ENABLE_NPN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_NPN, LO);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_NPN))
        errlong("CURLOPT_SSL_ENABLE_NPN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_NPN, HI);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_NPN))
        errlong("CURLOPT_SSL_ENABLE_NPN", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_ENABLE_ALPN ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_ALPN, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_ENABLE_ALPN))
      errlongzero("CURLOPT_SSL_ENABLE_ALPN", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_ALPN, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_ALPN))
        errlong("CURLOPT_SSL_ENABLE_ALPN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_ALPN, LO);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_ALPN))
        errlong("CURLOPT_SSL_ENABLE_ALPN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_ENABLE_ALPN, HI);
      if(res && !bad_long(res, CURLOPT_SSL_ENABLE_ALPN))
        errlong("CURLOPT_SSL_ENABLE_ALPN", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_EXPECT_100_TIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_EXPECT_100_TIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_EXPECT_100_TIMEOUT_MS))
      errlongzero("CURLOPT_EXPECT_100_TIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_EXPECT_100_TIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_EXPECT_100_TIMEOUT_MS))
        errlong("CURLOPT_EXPECT_100_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_EXPECT_100_TIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_EXPECT_100_TIMEOUT_MS))
        errlong("CURLOPT_EXPECT_100_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_EXPECT_100_TIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_EXPECT_100_TIMEOUT_MS))
        errlong("CURLOPT_EXPECT_100_TIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXYHEADER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXYHEADER, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PROXYHEADER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXYHEADER, NULL);
      if(res)
        errnull("CURLOPT_PROXYHEADER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HEADEROPT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HEADEROPT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HEADEROPT))
      errlongzero("CURLOPT_HEADEROPT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HEADEROPT, 22L);
      if(res && !bad_long(res, CURLOPT_HEADEROPT))
        errlong("CURLOPT_HEADEROPT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HEADEROPT, LO);
      if(res && !bad_long(res, CURLOPT_HEADEROPT))
        errlong("CURLOPT_HEADEROPT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HEADEROPT, HI);
      if(res && !bad_long(res, CURLOPT_HEADEROPT))
        errlong("CURLOPT_HEADEROPT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PINNEDPUBLICKEY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PINNEDPUBLICKEY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PINNEDPUBLICKEY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PINNEDPUBLICKEY, NULL);
      if(res)
        errnull("CURLOPT_PINNEDPUBLICKEY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_UNIX_SOCKET_PATH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_UNIX_SOCKET_PATH, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_UNIX_SOCKET_PATH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_UNIX_SOCKET_PATH, NULL);
      if(res)
        errnull("CURLOPT_UNIX_SOCKET_PATH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_VERIFYSTATUS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_VERIFYSTATUS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_VERIFYSTATUS))
      errlongzero("CURLOPT_SSL_VERIFYSTATUS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYSTATUS, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYSTATUS))
        errlong("CURLOPT_SSL_VERIFYSTATUS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYSTATUS, LO);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYSTATUS))
        errlong("CURLOPT_SSL_VERIFYSTATUS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_VERIFYSTATUS, HI);
      if(res && !bad_long(res, CURLOPT_SSL_VERIFYSTATUS))
        errlong("CURLOPT_SSL_VERIFYSTATUS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_FALSESTART ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_FALSESTART, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSL_FALSESTART))
      errlongzero("CURLOPT_SSL_FALSESTART", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_FALSESTART, 22L);
      if(res && !bad_long(res, CURLOPT_SSL_FALSESTART))
        errlong("CURLOPT_SSL_FALSESTART", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_FALSESTART, LO);
      if(res && !bad_long(res, CURLOPT_SSL_FALSESTART))
        errlong("CURLOPT_SSL_FALSESTART", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSL_FALSESTART, HI);
      if(res && !bad_long(res, CURLOPT_SSL_FALSESTART))
        errlong("CURLOPT_SSL_FALSESTART", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PATH_AS_IS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PATH_AS_IS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PATH_AS_IS))
      errlongzero("CURLOPT_PATH_AS_IS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PATH_AS_IS, 22L);
      if(res && !bad_long(res, CURLOPT_PATH_AS_IS))
        errlong("CURLOPT_PATH_AS_IS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PATH_AS_IS, LO);
      if(res && !bad_long(res, CURLOPT_PATH_AS_IS))
        errlong("CURLOPT_PATH_AS_IS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PATH_AS_IS, HI);
      if(res && !bad_long(res, CURLOPT_PATH_AS_IS))
        errlong("CURLOPT_PATH_AS_IS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SERVICE_NAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SERVICE_NAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SERVICE_NAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SERVICE_NAME, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SERVICE_NAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SERVICE_NAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SERVICE_NAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SERVICE_NAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SERVICE_NAME, NULL);
      if(res)
        errnull("CURLOPT_SERVICE_NAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PIPEWAIT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PIPEWAIT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PIPEWAIT))
      errlongzero("CURLOPT_PIPEWAIT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PIPEWAIT, 22L);
      if(res && !bad_long(res, CURLOPT_PIPEWAIT))
        errlong("CURLOPT_PIPEWAIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PIPEWAIT, LO);
      if(res && !bad_long(res, CURLOPT_PIPEWAIT))
        errlong("CURLOPT_PIPEWAIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PIPEWAIT, HI);
      if(res && !bad_long(res, CURLOPT_PIPEWAIT))
        errlong("CURLOPT_PIPEWAIT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DEFAULT_PROTOCOL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DEFAULT_PROTOCOL, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DEFAULT_PROTOCOL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DEFAULT_PROTOCOL, NULL);
      if(res)
        errnull("CURLOPT_DEFAULT_PROTOCOL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_STREAM_WEIGHT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_STREAM_WEIGHT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_STREAM_WEIGHT))
      errlongzero("CURLOPT_STREAM_WEIGHT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_STREAM_WEIGHT, 22L);
      if(res && !bad_long(res, CURLOPT_STREAM_WEIGHT))
        errlong("CURLOPT_STREAM_WEIGHT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_STREAM_WEIGHT, LO);
      if(res && !bad_long(res, CURLOPT_STREAM_WEIGHT))
        errlong("CURLOPT_STREAM_WEIGHT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_STREAM_WEIGHT, HI);
      if(res && !bad_long(res, CURLOPT_STREAM_WEIGHT))
        errlong("CURLOPT_STREAM_WEIGHT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_STREAM_DEPENDS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_STREAM_DEPENDS, dep);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_STREAM_DEPENDS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_STREAM_DEPENDS, NULL);
      if(res)
        errnull("CURLOPT_STREAM_DEPENDS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_STREAM_DEPENDS_E ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_STREAM_DEPENDS_E, dep);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_STREAM_DEPENDS_E", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_STREAM_DEPENDS_E, NULL);
      if(res)
        errnull("CURLOPT_STREAM_DEPENDS_E", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TFTP_NO_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TFTP_NO_OPTIONS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TFTP_NO_OPTIONS))
      errlongzero("CURLOPT_TFTP_NO_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TFTP_NO_OPTIONS, 22L);
      if(res && !bad_long(res, CURLOPT_TFTP_NO_OPTIONS))
        errlong("CURLOPT_TFTP_NO_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TFTP_NO_OPTIONS, LO);
      if(res && !bad_long(res, CURLOPT_TFTP_NO_OPTIONS))
        errlong("CURLOPT_TFTP_NO_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TFTP_NO_OPTIONS, HI);
      if(res && !bad_long(res, CURLOPT_TFTP_NO_OPTIONS))
        errlong("CURLOPT_TFTP_NO_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CONNECT_TO ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CONNECT_TO, slist);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CONNECT_TO", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CONNECT_TO, NULL);
      if(res)
        errnull("CURLOPT_CONNECT_TO", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_FASTOPEN ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_FASTOPEN, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_FASTOPEN))
      errlongzero("CURLOPT_TCP_FASTOPEN", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_FASTOPEN, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_FASTOPEN))
        errlong("CURLOPT_TCP_FASTOPEN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_FASTOPEN, LO);
      if(res && !bad_long(res, CURLOPT_TCP_FASTOPEN))
        errlong("CURLOPT_TCP_FASTOPEN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_FASTOPEN, HI);
      if(res && !bad_long(res, CURLOPT_TCP_FASTOPEN))
        errlong("CURLOPT_TCP_FASTOPEN", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_KEEP_SENDING_ON_ERROR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_KEEP_SENDING_ON_ERROR, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_KEEP_SENDING_ON_ERROR))
      errlongzero("CURLOPT_KEEP_SENDING_ON_ERROR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_KEEP_SENDING_ON_ERROR, 22L);
      if(res && !bad_long(res, CURLOPT_KEEP_SENDING_ON_ERROR))
        errlong("CURLOPT_KEEP_SENDING_ON_ERROR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_KEEP_SENDING_ON_ERROR, LO);
      if(res && !bad_long(res, CURLOPT_KEEP_SENDING_ON_ERROR))
        errlong("CURLOPT_KEEP_SENDING_ON_ERROR", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_KEEP_SENDING_ON_ERROR, HI);
      if(res && !bad_long(res, CURLOPT_KEEP_SENDING_ON_ERROR))
        errlong("CURLOPT_KEEP_SENDING_ON_ERROR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_CAINFO ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_CAINFO, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_CAINFO", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_CAINFO, NULL);
      if(res)
        errnull("CURLOPT_PROXY_CAINFO", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_CAPATH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_CAPATH, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_CAPATH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_CAPATH, NULL);
      if(res)
        errnull("CURLOPT_PROXY_CAPATH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSL_VERIFYPEER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYPEER, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXY_SSL_VERIFYPEER))
      errlongzero("CURLOPT_PROXY_SSL_VERIFYPEER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYPEER, 22L);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYPEER))
        errlong("CURLOPT_PROXY_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYPEER, LO);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYPEER))
        errlong("CURLOPT_PROXY_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYPEER, HI);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYPEER))
        errlong("CURLOPT_PROXY_SSL_VERIFYPEER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSL_VERIFYHOST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYHOST, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXY_SSL_VERIFYHOST))
      errlongzero("CURLOPT_PROXY_SSL_VERIFYHOST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYHOST, 22L);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYHOST))
        errlong("CURLOPT_PROXY_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYHOST, LO);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYHOST))
        errlong("CURLOPT_PROXY_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_VERIFYHOST, HI);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_VERIFYHOST))
        errlong("CURLOPT_PROXY_SSL_VERIFYHOST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLVERSION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLVERSION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXY_SSLVERSION))
      errlongzero("CURLOPT_PROXY_SSLVERSION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLVERSION, 22L);
      if(res && !bad_long(res, CURLOPT_PROXY_SSLVERSION))
        errlong("CURLOPT_PROXY_SSLVERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLVERSION, LO);
      if(res && !bad_long(res, CURLOPT_PROXY_SSLVERSION))
        errlong("CURLOPT_PROXY_SSLVERSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLVERSION, HI);
      if(res && !bad_long(res, CURLOPT_PROXY_SSLVERSION))
        errlong("CURLOPT_PROXY_SSLVERSION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_TLSAUTH_USERNAME ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_USERNAME, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_TLSAUTH_USERNAME", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_USERNAME, NULL);
      if(res)
        errnull("CURLOPT_PROXY_TLSAUTH_USERNAME", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_TLSAUTH_PASSWORD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_PASSWORD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_TLSAUTH_PASSWORD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_PASSWORD, NULL);
      if(res)
        errnull("CURLOPT_PROXY_TLSAUTH_PASSWORD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_TLSAUTH_TYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_TYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_TLSAUTH_TYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TLSAUTH_TYPE, NULL);
      if(res)
        errnull("CURLOPT_PROXY_TLSAUTH_TYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLCERT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SSLCERT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERT, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLCERT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLCERTTYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERTTYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SSLCERTTYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERTTYPE, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLCERTTYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLKEY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SSLKEY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEY, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLKEY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLKEYTYPE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEYTYPE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SSLKEYTYPE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEYTYPE, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLKEYTYPE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_KEYPASSWD ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_KEYPASSWD, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_KEYPASSWD", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_KEYPASSWD, NULL);
      if(res)
        errnull("CURLOPT_PROXY_KEYPASSWD", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSL_CIPHER_LIST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSL_CIPHER_LIST, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_SSL_CIPHER_LIST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_CIPHER_LIST, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSL_CIPHER_LIST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_CRLFILE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_CRLFILE, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_CRLFILE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_CRLFILE, NULL);
      if(res)
        errnull("CURLOPT_PROXY_CRLFILE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSL_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSL_OPTIONS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_PROXY_SSL_OPTIONS))
      errlongzero("CURLOPT_PROXY_SSL_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_OPTIONS, 22L);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_OPTIONS))
        errlong("CURLOPT_PROXY_SSL_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_OPTIONS, LO);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_OPTIONS))
        errlong("CURLOPT_PROXY_SSL_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSL_OPTIONS, HI);
      if(res && !bad_long(res, CURLOPT_PROXY_SSL_OPTIONS))
        errlong("CURLOPT_PROXY_SSL_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PRE_PROXY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PRE_PROXY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PRE_PROXY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PRE_PROXY, NULL);
      if(res)
        errnull("CURLOPT_PRE_PROXY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_PINNEDPUBLICKEY ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_PINNEDPUBLICKEY, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_PINNEDPUBLICKEY", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_PINNEDPUBLICKEY, NULL);
      if(res)
        errnull("CURLOPT_PROXY_PINNEDPUBLICKEY", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ABSTRACT_UNIX_SOCKET ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ABSTRACT_UNIX_SOCKET, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_ABSTRACT_UNIX_SOCKET", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ABSTRACT_UNIX_SOCKET, NULL);
      if(res)
        errnull("CURLOPT_ABSTRACT_UNIX_SOCKET", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SUPPRESS_CONNECT_HEADERS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SUPPRESS_CONNECT_HEADERS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SUPPRESS_CONNECT_HEADERS))
      errlongzero("CURLOPT_SUPPRESS_CONNECT_HEADERS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SUPPRESS_CONNECT_HEADERS, 22L);
      if(res && !bad_long(res, CURLOPT_SUPPRESS_CONNECT_HEADERS))
        errlong("CURLOPT_SUPPRESS_CONNECT_HEADERS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SUPPRESS_CONNECT_HEADERS, LO);
      if(res && !bad_long(res, CURLOPT_SUPPRESS_CONNECT_HEADERS))
        errlong("CURLOPT_SUPPRESS_CONNECT_HEADERS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SUPPRESS_CONNECT_HEADERS, HI);
      if(res && !bad_long(res, CURLOPT_SUPPRESS_CONNECT_HEADERS))
        errlong("CURLOPT_SUPPRESS_CONNECT_HEADERS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_REQUEST_TARGET ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_REQUEST_TARGET, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_REQUEST_TARGET", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_REQUEST_TARGET, NULL);
      if(res)
        errnull("CURLOPT_REQUEST_TARGET", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SOCKS5_AUTH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SOCKS5_AUTH, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SOCKS5_AUTH))
      errlongzero("CURLOPT_SOCKS5_AUTH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_AUTH, 22L);
      if(res && !bad_long(res, CURLOPT_SOCKS5_AUTH))
        errlong("CURLOPT_SOCKS5_AUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_AUTH, LO);
      if(res && !bad_long(res, CURLOPT_SOCKS5_AUTH))
        errlong("CURLOPT_SOCKS5_AUTH", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SOCKS5_AUTH, HI);
      if(res && !bad_long(res, CURLOPT_SOCKS5_AUTH))
        errlong("CURLOPT_SOCKS5_AUTH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_COMPRESSION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_COMPRESSION, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SSH_COMPRESSION))
      errlongzero("CURLOPT_SSH_COMPRESSION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_COMPRESSION, 22L);
      if(res && !bad_long(res, CURLOPT_SSH_COMPRESSION))
        errlong("CURLOPT_SSH_COMPRESSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSH_COMPRESSION, LO);
      if(res && !bad_long(res, CURLOPT_SSH_COMPRESSION))
        errlong("CURLOPT_SSH_COMPRESSION", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SSH_COMPRESSION, HI);
      if(res && !bad_long(res, CURLOPT_SSH_COMPRESSION))
        errlong("CURLOPT_SSH_COMPRESSION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MIMEPOST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MIMEPOST, mimepost);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_MIMEPOST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MIMEPOST, NULL);
      if(res)
        errnull("CURLOPT_MIMEPOST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TIMEVALUE_LARGE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TIMEVALUE_LARGE, OFF_NO);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TIMEVALUE_LARGE))
      errlongzero("CURLOPT_TIMEVALUE_LARGE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE_LARGE,
                             (curl_off_t)22);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE_LARGE))
        errlong("CURLOPT_TIMEVALUE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE_LARGE, OFF_HI);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE_LARGE))
        errlong("CURLOPT_TIMEVALUE_LARGE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TIMEVALUE_LARGE, OFF_LO);
      if(res && !bad_long(res, CURLOPT_TIMEVALUE_LARGE))
        errlong("CURLOPT_TIMEVALUE_LARGE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS))
      errlongzero("CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS))
        errlong("CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS))
        errlong("CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS))
        errlong("CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RESOLVER_START_FUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RESOLVER_START_FUNCTION,
                           resolver_start_cb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_RESOLVER_START_FUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RESOLVER_START_FUNCTION, NULL);
      if(res)
        errnull("CURLOPT_RESOLVER_START_FUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_RESOLVER_START_DATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_RESOLVER_START_DATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_RESOLVER_START_DATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_RESOLVER_START_DATA, NULL);
      if(res)
        errnull("CURLOPT_RESOLVER_START_DATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HAPROXYPROTOCOL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HAPROXYPROTOCOL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HAPROXYPROTOCOL))
      errlongzero("CURLOPT_HAPROXYPROTOCOL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HAPROXYPROTOCOL, 22L);
      if(res && !bad_long(res, CURLOPT_HAPROXYPROTOCOL))
        errlong("CURLOPT_HAPROXYPROTOCOL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HAPROXYPROTOCOL, LO);
      if(res && !bad_long(res, CURLOPT_HAPROXYPROTOCOL))
        errlong("CURLOPT_HAPROXYPROTOCOL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HAPROXYPROTOCOL, HI);
      if(res && !bad_long(res, CURLOPT_HAPROXYPROTOCOL))
        errlong("CURLOPT_HAPROXYPROTOCOL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DNS_SHUFFLE_ADDRESSES ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DNS_SHUFFLE_ADDRESSES, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DNS_SHUFFLE_ADDRESSES))
      errlongzero("CURLOPT_DNS_SHUFFLE_ADDRESSES", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DNS_SHUFFLE_ADDRESSES, 22L);
      if(res && !bad_long(res, CURLOPT_DNS_SHUFFLE_ADDRESSES))
        errlong("CURLOPT_DNS_SHUFFLE_ADDRESSES", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_SHUFFLE_ADDRESSES, LO);
      if(res && !bad_long(res, CURLOPT_DNS_SHUFFLE_ADDRESSES))
        errlong("CURLOPT_DNS_SHUFFLE_ADDRESSES", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DNS_SHUFFLE_ADDRESSES, HI);
      if(res && !bad_long(res, CURLOPT_DNS_SHUFFLE_ADDRESSES))
        errlong("CURLOPT_DNS_SHUFFLE_ADDRESSES", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TLS13_CIPHERS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TLS13_CIPHERS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_TLS13_CIPHERS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TLS13_CIPHERS, NULL);
      if(res)
        errnull("CURLOPT_TLS13_CIPHERS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_TLS13_CIPHERS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_TLS13_CIPHERS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_TLS13_CIPHERS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_TLS13_CIPHERS, NULL);
      if(res)
        errnull("CURLOPT_PROXY_TLS13_CIPHERS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DISALLOW_USERNAME_IN_URL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DISALLOW_USERNAME_IN_URL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DISALLOW_USERNAME_IN_URL))
      errlongzero("CURLOPT_DISALLOW_USERNAME_IN_URL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DISALLOW_USERNAME_IN_URL, 22L);
      if(res && !bad_long(res, CURLOPT_DISALLOW_USERNAME_IN_URL))
        errlong("CURLOPT_DISALLOW_USERNAME_IN_URL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DISALLOW_USERNAME_IN_URL, LO);
      if(res && !bad_long(res, CURLOPT_DISALLOW_USERNAME_IN_URL))
        errlong("CURLOPT_DISALLOW_USERNAME_IN_URL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DISALLOW_USERNAME_IN_URL, HI);
      if(res && !bad_long(res, CURLOPT_DISALLOW_USERNAME_IN_URL))
        errlong("CURLOPT_DISALLOW_USERNAME_IN_URL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DOH_URL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DOH_URL, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_DOH_URL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DOH_URL, NULL);
      if(res)
        errnull("CURLOPT_DOH_URL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_UPLOAD_BUFFERSIZE ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_UPLOAD_BUFFERSIZE, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_UPLOAD_BUFFERSIZE))
      errlongzero("CURLOPT_UPLOAD_BUFFERSIZE", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD_BUFFERSIZE, 22L);
      if(res && !bad_long(res, CURLOPT_UPLOAD_BUFFERSIZE))
        errlong("CURLOPT_UPLOAD_BUFFERSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD_BUFFERSIZE, LO);
      if(res && !bad_long(res, CURLOPT_UPLOAD_BUFFERSIZE))
        errlong("CURLOPT_UPLOAD_BUFFERSIZE", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPLOAD_BUFFERSIZE, HI);
      if(res && !bad_long(res, CURLOPT_UPLOAD_BUFFERSIZE))
        errlong("CURLOPT_UPLOAD_BUFFERSIZE", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_UPKEEP_INTERVAL_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_UPKEEP_INTERVAL_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_UPKEEP_INTERVAL_MS))
      errlongzero("CURLOPT_UPKEEP_INTERVAL_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_UPKEEP_INTERVAL_MS, 22L);
      if(res && !bad_long(res, CURLOPT_UPKEEP_INTERVAL_MS))
        errlong("CURLOPT_UPKEEP_INTERVAL_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPKEEP_INTERVAL_MS, LO);
      if(res && !bad_long(res, CURLOPT_UPKEEP_INTERVAL_MS))
        errlong("CURLOPT_UPKEEP_INTERVAL_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_UPKEEP_INTERVAL_MS, HI);
      if(res && !bad_long(res, CURLOPT_UPKEEP_INTERVAL_MS))
        errlong("CURLOPT_UPKEEP_INTERVAL_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CURLU ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CURLU, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_CURLU", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CURLU, NULL);
      if(res)
        errnull("CURLOPT_CURLU", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TRAILERFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TRAILERFUNCTION,
                           trailercb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_TRAILERFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TRAILERFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_TRAILERFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TRAILERDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TRAILERDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_TRAILERDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TRAILERDATA, NULL);
      if(res)
        errnull("CURLOPT_TRAILERDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HTTP09_ALLOWED ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HTTP09_ALLOWED, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HTTP09_ALLOWED))
      errlongzero("CURLOPT_HTTP09_ALLOWED", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HTTP09_ALLOWED, 22L);
      if(res && !bad_long(res, CURLOPT_HTTP09_ALLOWED))
        errlong("CURLOPT_HTTP09_ALLOWED", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP09_ALLOWED, LO);
      if(res && !bad_long(res, CURLOPT_HTTP09_ALLOWED))
        errlong("CURLOPT_HTTP09_ALLOWED", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HTTP09_ALLOWED, HI);
      if(res && !bad_long(res, CURLOPT_HTTP09_ALLOWED))
        errlong("CURLOPT_HTTP09_ALLOWED", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ALTSVC_CTRL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ALTSVC_CTRL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_ALTSVC_CTRL))
      errlongzero("CURLOPT_ALTSVC_CTRL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ALTSVC_CTRL, 22L);
      if(res && !bad_long(res, CURLOPT_ALTSVC_CTRL))
        errlong("CURLOPT_ALTSVC_CTRL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ALTSVC_CTRL, LO);
      if(res && !bad_long(res, CURLOPT_ALTSVC_CTRL))
        errlong("CURLOPT_ALTSVC_CTRL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_ALTSVC_CTRL, HI);
      if(res && !bad_long(res, CURLOPT_ALTSVC_CTRL))
        errlong("CURLOPT_ALTSVC_CTRL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ALTSVC ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ALTSVC, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_ALTSVC", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ALTSVC, NULL);
      if(res)
        errnull("CURLOPT_ALTSVC", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXAGE_CONN ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXAGE_CONN, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXAGE_CONN))
      errlongzero("CURLOPT_MAXAGE_CONN", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXAGE_CONN, 22L);
      if(res && !bad_long(res, CURLOPT_MAXAGE_CONN))
        errlong("CURLOPT_MAXAGE_CONN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXAGE_CONN, LO);
      if(res && !bad_long(res, CURLOPT_MAXAGE_CONN))
        errlong("CURLOPT_MAXAGE_CONN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXAGE_CONN, HI);
      if(res && !bad_long(res, CURLOPT_MAXAGE_CONN))
        errlong("CURLOPT_MAXAGE_CONN", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SASL_AUTHZID ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SASL_AUTHZID, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SASL_AUTHZID", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SASL_AUTHZID, NULL);
      if(res)
        errnull("CURLOPT_SASL_AUTHZID", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAIL_RCPT_ALLOWFAILS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAIL_RCPT_ALLOWFAILS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAIL_RCPT_ALLOWFAILS))
      errlongzero("CURLOPT_MAIL_RCPT_ALLOWFAILS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAIL_RCPT_ALLOWFAILS, 22L);
      if(res && !bad_long(res, CURLOPT_MAIL_RCPT_ALLOWFAILS))
        errlong("CURLOPT_MAIL_RCPT_ALLOWFAILS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAIL_RCPT_ALLOWFAILS, LO);
      if(res && !bad_long(res, CURLOPT_MAIL_RCPT_ALLOWFAILS))
        errlong("CURLOPT_MAIL_RCPT_ALLOWFAILS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAIL_RCPT_ALLOWFAILS, HI);
      if(res && !bad_long(res, CURLOPT_MAIL_RCPT_ALLOWFAILS))
        errlong("CURLOPT_MAIL_RCPT_ALLOWFAILS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLCERT_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLCERT_BLOB, &blob);
      if(res)
        err("CURLOPT_SSLCERT_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLCERT_BLOB, NULL);
      if(res)
        errnull("CURLOPT_SSLCERT_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSLKEY_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSLKEY_BLOB, &blob);
      if(res)
        err("CURLOPT_SSLKEY_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSLKEY_BLOB, NULL);
      if(res)
        errnull("CURLOPT_SSLKEY_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLCERT_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERT_BLOB, &blob);
      if(res)
        err("CURLOPT_PROXY_SSLCERT_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLCERT_BLOB, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLCERT_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_SSLKEY_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEY_BLOB, &blob);
      if(res)
        err("CURLOPT_PROXY_SSLKEY_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_SSLKEY_BLOB, NULL);
      if(res)
        errnull("CURLOPT_PROXY_SSLKEY_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ISSUERCERT_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ISSUERCERT_BLOB, &blob);
      if(res)
        err("CURLOPT_ISSUERCERT_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ISSUERCERT_BLOB, NULL);
      if(res)
        errnull("CURLOPT_ISSUERCERT_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_ISSUERCERT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_ISSUERCERT, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROXY_ISSUERCERT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_ISSUERCERT, NULL);
      if(res)
        errnull("CURLOPT_PROXY_ISSUERCERT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_ISSUERCERT_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_ISSUERCERT_BLOB, &blob);
      if(res)
        err("CURLOPT_PROXY_ISSUERCERT_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_ISSUERCERT_BLOB, NULL);
      if(res)
        errnull("CURLOPT_PROXY_ISSUERCERT_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSL_EC_CURVES ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSL_EC_CURVES, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSL_EC_CURVES", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSL_EC_CURVES, NULL);
      if(res)
        errnull("CURLOPT_SSL_EC_CURVES", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTS_CTRL ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTS_CTRL, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_HSTS_CTRL))
      errlongzero("CURLOPT_HSTS_CTRL", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTS_CTRL, 22L);
      if(res && !bad_long(res, CURLOPT_HSTS_CTRL))
        errlong("CURLOPT_HSTS_CTRL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HSTS_CTRL, LO);
      if(res && !bad_long(res, CURLOPT_HSTS_CTRL))
        errlong("CURLOPT_HSTS_CTRL", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_HSTS_CTRL, HI);
      if(res && !bad_long(res, CURLOPT_HSTS_CTRL))
        errlong("CURLOPT_HSTS_CTRL", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTS, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_HSTS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTS, NULL);
      if(res)
        errnull("CURLOPT_HSTS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTSREADFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTSREADFUNCTION,
                           hstsreadcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HSTSREADFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTSREADFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_HSTSREADFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTSREADDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTSREADDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HSTSREADDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTSREADDATA, NULL);
      if(res)
        errnull("CURLOPT_HSTSREADDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTSWRITEFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTSWRITEFUNCTION,
                           hstswritecb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HSTSWRITEFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTSWRITEFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_HSTSWRITEFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HSTSWRITEDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HSTSWRITEDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_HSTSWRITEDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HSTSWRITEDATA, NULL);
      if(res)
        errnull("CURLOPT_HSTSWRITEDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_AWS_SIGV4 ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_AWS_SIGV4, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_AWS_SIGV4", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_AWS_SIGV4, NULL);
      if(res)
        errnull("CURLOPT_AWS_SIGV4", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DOH_SSL_VERIFYPEER ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYPEER, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DOH_SSL_VERIFYPEER))
      errlongzero("CURLOPT_DOH_SSL_VERIFYPEER", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYPEER, 22L);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYPEER))
        errlong("CURLOPT_DOH_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYPEER, LO);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYPEER))
        errlong("CURLOPT_DOH_SSL_VERIFYPEER", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYPEER, HI);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYPEER))
        errlong("CURLOPT_DOH_SSL_VERIFYPEER", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DOH_SSL_VERIFYHOST ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYHOST, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DOH_SSL_VERIFYHOST))
      errlongzero("CURLOPT_DOH_SSL_VERIFYHOST", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYHOST, 22L);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYHOST))
        errlong("CURLOPT_DOH_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYHOST, LO);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYHOST))
        errlong("CURLOPT_DOH_SSL_VERIFYHOST", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYHOST, HI);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYHOST))
        errlong("CURLOPT_DOH_SSL_VERIFYHOST", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_DOH_SSL_VERIFYSTATUS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYSTATUS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_DOH_SSL_VERIFYSTATUS))
      errlongzero("CURLOPT_DOH_SSL_VERIFYSTATUS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYSTATUS, 22L);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYSTATUS))
        errlong("CURLOPT_DOH_SSL_VERIFYSTATUS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYSTATUS, LO);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYSTATUS))
        errlong("CURLOPT_DOH_SSL_VERIFYSTATUS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_DOH_SSL_VERIFYSTATUS, HI);
      if(res && !bad_long(res, CURLOPT_DOH_SSL_VERIFYSTATUS))
        errlong("CURLOPT_DOH_SSL_VERIFYSTATUS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CAINFO_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CAINFO_BLOB, &blob);
      if(res)
        err("CURLOPT_CAINFO_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CAINFO_BLOB, NULL);
      if(res)
        errnull("CURLOPT_CAINFO_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROXY_CAINFO_BLOB ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROXY_CAINFO_BLOB, &blob);
      if(res)
        err("CURLOPT_PROXY_CAINFO_BLOB", res, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROXY_CAINFO_BLOB, NULL);
      if(res)
        errnull("CURLOPT_PROXY_CAINFO_BLOB", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256 ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256, NULL);
      if(res)
        errnull("CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PREREQFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PREREQFUNCTION,
                           prereqcb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PREREQFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PREREQFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_PREREQFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PREREQDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PREREQDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_PREREQDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PREREQDATA, NULL);
      if(res)
        errnull("CURLOPT_PREREQDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MAXLIFETIME_CONN ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MAXLIFETIME_CONN, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MAXLIFETIME_CONN))
      errlongzero("CURLOPT_MAXLIFETIME_CONN", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MAXLIFETIME_CONN, 22L);
      if(res && !bad_long(res, CURLOPT_MAXLIFETIME_CONN))
        errlong("CURLOPT_MAXLIFETIME_CONN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXLIFETIME_CONN, LO);
      if(res && !bad_long(res, CURLOPT_MAXLIFETIME_CONN))
        errlong("CURLOPT_MAXLIFETIME_CONN", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MAXLIFETIME_CONN, HI);
      if(res && !bad_long(res, CURLOPT_MAXLIFETIME_CONN))
        errlong("CURLOPT_MAXLIFETIME_CONN", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_MIME_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_MIME_OPTIONS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_MIME_OPTIONS))
      errlongzero("CURLOPT_MIME_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_MIME_OPTIONS, 22L);
      if(res && !bad_long(res, CURLOPT_MIME_OPTIONS))
        errlong("CURLOPT_MIME_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MIME_OPTIONS, LO);
      if(res && !bad_long(res, CURLOPT_MIME_OPTIONS))
        errlong("CURLOPT_MIME_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_MIME_OPTIONS, HI);
      if(res && !bad_long(res, CURLOPT_MIME_OPTIONS))
        errlong("CURLOPT_MIME_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_HOSTKEYFUNCTION ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_HOSTKEYFUNCTION,
                           ssh_hostkeycb);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSH_HOSTKEYFUNCTION", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_HOSTKEYFUNCTION, NULL);
      if(res)
        errnull("CURLOPT_SSH_HOSTKEYFUNCTION", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SSH_HOSTKEYDATA ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SSH_HOSTKEYDATA, &object);
    if(first && present(first)) /* first setopt check only */
      err("CURLOPT_SSH_HOSTKEYDATA", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SSH_HOSTKEYDATA, NULL);
      if(res)
        errnull("CURLOPT_SSH_HOSTKEYDATA", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_PROTOCOLS_STR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_PROTOCOLS_STR, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_PROTOCOLS_STR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_PROTOCOLS_STR, NULL);
      if(res)
        errnull("CURLOPT_PROTOCOLS_STR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_REDIR_PROTOCOLS_STR ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS_STR, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_REDIR_PROTOCOLS_STR", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_REDIR_PROTOCOLS_STR, NULL);
      if(res)
        errnull("CURLOPT_REDIR_PROTOCOLS_STR", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_WS_OPTIONS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_WS_OPTIONS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_WS_OPTIONS))
      errlongzero("CURLOPT_WS_OPTIONS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_WS_OPTIONS, 22L);
      if(res && !bad_long(res, CURLOPT_WS_OPTIONS))
        errlong("CURLOPT_WS_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_WS_OPTIONS, LO);
      if(res && !bad_long(res, CURLOPT_WS_OPTIONS))
        errlong("CURLOPT_WS_OPTIONS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_WS_OPTIONS, HI);
      if(res && !bad_long(res, CURLOPT_WS_OPTIONS))
        errlong("CURLOPT_WS_OPTIONS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_CA_CACHE_TIMEOUT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_CA_CACHE_TIMEOUT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_CA_CACHE_TIMEOUT))
      errlongzero("CURLOPT_CA_CACHE_TIMEOUT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_CA_CACHE_TIMEOUT, 22L);
      if(res && !bad_long(res, CURLOPT_CA_CACHE_TIMEOUT))
        errlong("CURLOPT_CA_CACHE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CA_CACHE_TIMEOUT, LO);
      if(res && !bad_long(res, CURLOPT_CA_CACHE_TIMEOUT))
        errlong("CURLOPT_CA_CACHE_TIMEOUT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_CA_CACHE_TIMEOUT, HI);
      if(res && !bad_long(res, CURLOPT_CA_CACHE_TIMEOUT))
        errlong("CURLOPT_CA_CACHE_TIMEOUT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_QUICK_EXIT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_QUICK_EXIT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_QUICK_EXIT))
      errlongzero("CURLOPT_QUICK_EXIT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_QUICK_EXIT, 22L);
      if(res && !bad_long(res, CURLOPT_QUICK_EXIT))
        errlong("CURLOPT_QUICK_EXIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_QUICK_EXIT, LO);
      if(res && !bad_long(res, CURLOPT_QUICK_EXIT))
        errlong("CURLOPT_QUICK_EXIT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_QUICK_EXIT, HI);
      if(res && !bad_long(res, CURLOPT_QUICK_EXIT))
        errlong("CURLOPT_QUICK_EXIT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_HAPROXY_CLIENT_IP ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_HAPROXY_CLIENT_IP, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_HAPROXY_CLIENT_IP", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_HAPROXY_CLIENT_IP, NULL);
      if(res)
        errnull("CURLOPT_HAPROXY_CLIENT_IP", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_SERVER_RESPONSE_TIMEOUT_MS ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_SERVER_RESPONSE_TIMEOUT_MS))
      errlongzero("CURLOPT_SERVER_RESPONSE_TIMEOUT_MS", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS, 22L);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS, LO);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT_MS", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS, HI);
      if(res && !bad_long(res, CURLOPT_SERVER_RESPONSE_TIMEOUT_MS))
        errlong("CURLOPT_SERVER_RESPONSE_TIMEOUT_MS", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_ECH ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_ECH, "string");
    if(first && present(first)) /* first setopt check only */
      errstring("CURLOPT_ECH", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_ECH, NULL);
      if(res)
        errnull("CURLOPT_ECH", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */

  /****** Verify CURLOPT_TCP_KEEPCNT ******/
  {
    CURLcode first =
      curl_easy_setopt(curl, CURLOPT_TCP_KEEPCNT, 0L);
    if(first && present(first) && !bad_long(first,
       CURLOPT_TCP_KEEPCNT))
      errlongzero("CURLOPT_TCP_KEEPCNT", first, __LINE__);
    if(present(first)) {
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPCNT, 22L);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPCNT))
        errlong("CURLOPT_TCP_KEEPCNT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPCNT, LO);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPCNT))
        errlong("CURLOPT_TCP_KEEPCNT", res, __LINE__);
      res = curl_easy_setopt(curl, CURLOPT_TCP_KEEPCNT, HI);
      if(res && !bad_long(res, CURLOPT_TCP_KEEPCNT))
        errlong("CURLOPT_TCP_KEEPCNT", res, __LINE__);
    } /* end of secondary checks */
  } /* end of single setopt */
  res = curl_easy_getinfo(curl, CURLINFO_EFFECTIVE_URL, &charp);
  if(res)
    geterr("EFFECTIVE_URL", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &val);
  if(res)
    geterr("RESPONSE_CODE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_TOTAL_TIME, &dval);
  if(res)
    geterr("TOTAL_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_NAMELOOKUP_TIME, &dval);
  if(res)
    geterr("NAMELOOKUP_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONNECT_TIME, &dval);
  if(res)
    geterr("CONNECT_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PRETRANSFER_TIME, &dval);
  if(res)
    geterr("PRETRANSFER_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SIZE_UPLOAD, &dval);
  if(res)
    geterr("SIZE_UPLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SIZE_UPLOAD_T, &oval);
  if(res)
    geterr("SIZE_UPLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SIZE_DOWNLOAD, &dval);
  if(res)
    geterr("SIZE_DOWNLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SIZE_DOWNLOAD_T, &oval);
  if(res)
    geterr("SIZE_DOWNLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SPEED_DOWNLOAD, &dval);
  if(res)
    geterr("SPEED_DOWNLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SPEED_DOWNLOAD_T, &oval);
  if(res)
    geterr("SPEED_DOWNLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SPEED_UPLOAD, &dval);
  if(res)
    geterr("SPEED_UPLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SPEED_UPLOAD_T, &oval);
  if(res)
    geterr("SPEED_UPLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_HEADER_SIZE, &val);
  if(res)
    geterr("HEADER_SIZE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REQUEST_SIZE, &val);
  if(res)
    geterr("REQUEST_SIZE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SSL_VERIFYRESULT, &val);
  if(res)
    geterr("SSL_VERIFYRESULT", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_FILETIME, &val);
  if(res)
    geterr("FILETIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_FILETIME_T, &oval);
  if(res)
    geterr("FILETIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &dval);
  if(res)
    geterr("CONTENT_LENGTH_DOWNLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T, &oval);
  if(res)
    geterr("CONTENT_LENGTH_DOWNLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONTENT_LENGTH_UPLOAD, &dval);
  if(res)
    geterr("CONTENT_LENGTH_UPLOAD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONTENT_LENGTH_UPLOAD_T, &oval);
  if(res)
    geterr("CONTENT_LENGTH_UPLOAD_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_STARTTRANSFER_TIME, &dval);
  if(res)
    geterr("STARTTRANSFER_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONTENT_TYPE, &charp);
  if(res)
    geterr("CONTENT_TYPE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REDIRECT_TIME, &dval);
  if(res)
    geterr("REDIRECT_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REDIRECT_COUNT, &val);
  if(res)
    geterr("REDIRECT_COUNT", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PRIVATE, &charp);
  if(res)
    geterr("PRIVATE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_HTTP_CONNECTCODE, &val);
  if(res)
    geterr("HTTP_CONNECTCODE", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_HTTPAUTH_AVAIL, &val);
  if(res)
    geterr("HTTPAUTH_AVAIL", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PROXYAUTH_AVAIL, &val);
  if(res)
    geterr("PROXYAUTH_AVAIL", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_OS_ERRNO, &val);
  if(res)
    geterr("OS_ERRNO", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_NUM_CONNECTS, &val);
  if(res)
    geterr("NUM_CONNECTS", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SSL_ENGINES, &slist);
  if(res)
    geterr("SSL_ENGINES", res, __LINE__);
  if(slist)
    curl_slist_free_all(slist);
  res = curl_easy_getinfo(curl, CURLINFO_COOKIELIST, &slist);
  if(res)
    geterr("COOKIELIST", res, __LINE__);
  if(slist)
    curl_slist_free_all(slist);
  res = curl_easy_getinfo(curl, CURLINFO_LASTSOCKET, &val);
  if(res)
    geterr("LASTSOCKET", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_FTP_ENTRY_PATH, &charp);
  if(res)
    geterr("FTP_ENTRY_PATH", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REDIRECT_URL, &charp);
  if(res)
    geterr("REDIRECT_URL", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PRIMARY_IP, &charp);
  if(res)
    geterr("PRIMARY_IP", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_APPCONNECT_TIME, &dval);
  if(res)
    geterr("APPCONNECT_TIME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CERTINFO, &certinfo);
  if(res)
    geterr("CERTINFO", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONDITION_UNMET, &val);
  if(res)
    geterr("CONDITION_UNMET", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RTSP_SESSION_ID, &charp);
  if(res)
    geterr("RTSP_SESSION_ID", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RTSP_CLIENT_CSEQ, &val);
  if(res)
    geterr("RTSP_CLIENT_CSEQ", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RTSP_SERVER_CSEQ, &val);
  if(res)
    geterr("RTSP_SERVER_CSEQ", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RTSP_CSEQ_RECV, &val);
  if(res)
    geterr("RTSP_CSEQ_RECV", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PRIMARY_PORT, &val);
  if(res)
    geterr("PRIMARY_PORT", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_LOCAL_IP, &charp);
  if(res)
    geterr("LOCAL_IP", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_LOCAL_PORT, &val);
  if(res)
    geterr("LOCAL_PORT", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_TLS_SESSION, &tlssession);
  if(res)
    geterr("TLS_SESSION", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_ACTIVESOCKET, &sockfd);
  if(res)
    geterr("ACTIVESOCKET", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_TLS_SSL_PTR, &tlssession);
  if(res)
    geterr("TLS_SSL_PTR", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_HTTP_VERSION, &val);
  if(res)
    geterr("HTTP_VERSION", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PROXY_SSL_VERIFYRESULT, &val);
  if(res)
    geterr("PROXY_SSL_VERIFYRESULT", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PROTOCOL, &val);
  if(res)
    geterr("PROTOCOL", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_SCHEME, &charp);
  if(res)
    geterr("SCHEME", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_TOTAL_TIME_T, &oval);
  if(res)
    geterr("TOTAL_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_NAMELOOKUP_TIME_T, &oval);
  if(res)
    geterr("NAMELOOKUP_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONNECT_TIME_T, &oval);
  if(res)
    geterr("CONNECT_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PRETRANSFER_TIME_T, &oval);
  if(res)
    geterr("PRETRANSFER_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_STARTTRANSFER_TIME_T, &oval);
  if(res)
    geterr("STARTTRANSFER_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REDIRECT_TIME_T, &oval);
  if(res)
    geterr("REDIRECT_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_APPCONNECT_TIME_T, &oval);
  if(res)
    geterr("APPCONNECT_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_RETRY_AFTER, &oval);
  if(res)
    geterr("RETRY_AFTER", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_EFFECTIVE_METHOD, &charp);
  if(res)
    geterr("EFFECTIVE_METHOD", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_PROXY_ERROR, &val);
  if(res)
    geterr("PROXY_ERROR", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_REFERER, &charp);
  if(res)
    geterr("REFERER", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CAINFO, &charp);
  if(res)
    geterr("CAINFO", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CAPATH, &charp);
  if(res)
    geterr("CAPATH", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_XFER_ID, &oval);
  if(res)
    geterr("XFER_ID", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_CONN_ID, &oval);
  if(res)
    geterr("CONN_ID", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_QUEUE_TIME_T, &oval);
  if(res)
    geterr("QUEUE_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_USED_PROXY, &val);
  if(res)
    geterr("USED_PROXY", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_POSTTRANSFER_TIME_T, &oval);
  if(res)
    geterr("POSTTRANSFER_TIME_T", res, __LINE__);
  res = curl_easy_getinfo(curl, CURLINFO_EARLYDATA_SENT_T, &oval);
  if(res)
    geterr("EARLYDATA_SENT_T", res, __LINE__);
  )
  curl_easy_setopt(curl, (CURLoption)1, 0);
  res = CURLE_OK;
test_cleanup:
  curl_easy_cleanup(curl);
  curl_easy_cleanup(dep);
  curl_share_cleanup(share);
  curl_global_cleanup();

  if(!res)
    puts("ok");
  return res;
}
